import typing

import java
import java.chaquopy
import java.lang
import java.math
import java.security.spec
import javax.crypto

class ChaCha20ParameterSpec(java.security.spec.AlgorithmParameterSpec):
    def __init__(self, nonce: java.chaquopy.JavaArrayJByte, counter: int | java.jint | java.lang.Integer, /) -> None: ...
    def getCounter(self) -> int: ...
    def getNonce(self) -> java.chaquopy.JavaArrayJByte: ...

class DESKeySpec(java.security.spec.KeySpec):
    DES_KEY_LEN: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self, key: java.chaquopy.JavaArrayJByte, /) -> None: ...
    @typing.overload
    def __init__(self, key: java.chaquopy.JavaArrayJByte, offset: int | java.jint | java.lang.Integer, /) -> None: ...
    def getKey(self) -> java.chaquopy.JavaArrayJByte: ...
    @staticmethod
    def isParityAdjusted(key: java.chaquopy.JavaArrayJByte, offset: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def isWeak(key: java.chaquopy.JavaArrayJByte, offset: int | java.jint | java.lang.Integer, /) -> bool: ...

class DESedeKeySpec(java.security.spec.KeySpec):
    DES_EDE_KEY_LEN: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self, key: java.chaquopy.JavaArrayJByte, /) -> None: ...
    @typing.overload
    def __init__(self, key: java.chaquopy.JavaArrayJByte, offset: int | java.jint | java.lang.Integer, /) -> None: ...
    def getKey(self) -> java.chaquopy.JavaArrayJByte: ...
    @staticmethod
    def isParityAdjusted(key: java.chaquopy.JavaArrayJByte, offset: int | java.jint | java.lang.Integer, /) -> bool: ...

class DHGenParameterSpec(java.security.spec.AlgorithmParameterSpec):
    def __init__(self, primeSize: int | java.jint | java.lang.Integer, exponentSize: int | java.jint | java.lang.Integer, /) -> None: ...
    def getExponentSize(self) -> int: ...
    def getPrimeSize(self) -> int: ...

class DHParameterSpec(java.security.spec.AlgorithmParameterSpec):
    @typing.overload
    def __init__(self, p: java.math.BigInteger, g: java.math.BigInteger, /) -> None: ...
    @typing.overload
    def __init__(self, p: java.math.BigInteger, g: java.math.BigInteger, l: int | java.jint | java.lang.Integer, /) -> None: ...
    def getG(self) -> java.math.BigInteger: ...
    def getL(self) -> int: ...
    def getP(self) -> java.math.BigInteger: ...

class DHPrivateKeySpec(java.security.spec.KeySpec):
    def __init__(self, x: java.math.BigInteger, p: java.math.BigInteger, g: java.math.BigInteger, /) -> None: ...
    def getG(self) -> java.math.BigInteger: ...
    def getP(self) -> java.math.BigInteger: ...
    def getX(self) -> java.math.BigInteger: ...

class DHPublicKeySpec(java.security.spec.KeySpec):
    def __init__(self, y: java.math.BigInteger, p: java.math.BigInteger, g: java.math.BigInteger, /) -> None: ...
    def getG(self) -> java.math.BigInteger: ...
    def getP(self) -> java.math.BigInteger: ...
    def getY(self) -> java.math.BigInteger: ...

class GCMParameterSpec(java.security.spec.AlgorithmParameterSpec):
    @typing.overload
    def __init__(self, tLen: int | java.jint | java.lang.Integer, src: java.chaquopy.JavaArrayJByte, /) -> None: ...
    @typing.overload
    def __init__(self, tLen: int | java.jint | java.lang.Integer, src: java.chaquopy.JavaArrayJByte, offset: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> None: ...
    def getIV(self) -> java.chaquopy.JavaArrayJByte: ...
    def getTLen(self) -> int: ...

class IvParameterSpec(java.security.spec.AlgorithmParameterSpec):
    @typing.overload
    def __init__(self, iv: java.chaquopy.JavaArrayJByte, /) -> None: ...
    @typing.overload
    def __init__(self, iv: java.chaquopy.JavaArrayJByte, offset: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> None: ...
    def getIV(self) -> java.chaquopy.JavaArrayJByte: ...

class OAEPParameterSpec(java.security.spec.AlgorithmParameterSpec):
    DEFAULT: typing.ClassVar[OAEPParameterSpec] = ...
    def __init__(self, mdName: str | java.lang.String, mgfName: str | java.lang.String, mgfSpec: java.security.spec.AlgorithmParameterSpec, pSrc: PSource, /) -> None: ...
    def getDigestAlgorithm(self) -> str: ...
    def getMGFAlgorithm(self) -> str: ...
    def getMGFParameters(self) -> java.security.spec.AlgorithmParameterSpec: ...
    def getPSource(self) -> PSource: ...

class PBEKeySpec(java.security.spec.KeySpec):
    @typing.overload
    def __init__(self, password: java.chaquopy.JavaArrayJChar, /) -> None: ...
    @typing.overload
    def __init__(self, password: java.chaquopy.JavaArrayJChar, salt: java.chaquopy.JavaArrayJByte, iterationCount: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, password: java.chaquopy.JavaArrayJChar, salt: java.chaquopy.JavaArrayJByte, iterationCount: int | java.jint | java.lang.Integer, keyLength: int | java.jint | java.lang.Integer, /) -> None: ...
    def clearPassword(self) -> None: ...
    def getIterationCount(self) -> int: ...
    def getKeyLength(self) -> int: ...
    def getPassword(self) -> java.chaquopy.JavaArrayJChar: ...
    def getSalt(self) -> java.chaquopy.JavaArrayJByte: ...

class PBEParameterSpec(java.security.spec.AlgorithmParameterSpec):
    @typing.overload
    def __init__(self, salt: java.chaquopy.JavaArrayJByte, iterationCount: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, salt: java.chaquopy.JavaArrayJByte, iterationCount: int | java.jint | java.lang.Integer, paramSpec: java.security.spec.AlgorithmParameterSpec, /) -> None: ...
    def getIterationCount(self) -> int: ...
    def getParameterSpec(self) -> java.security.spec.AlgorithmParameterSpec: ...
    def getSalt(self) -> java.chaquopy.JavaArrayJByte: ...

class PSource(java.lang.Object):
    def __init__(self, pSrcName: str | java.lang.String, /) -> None: ...
    def getAlgorithm(self) -> str: ...

    class PSpecified(PSource):
        DEFAULT: typing.ClassVar[PSource.PSpecified] = ...
        def __init__(self, p: java.chaquopy.JavaArrayJByte, /) -> None: ...
        def getValue(self) -> java.chaquopy.JavaArrayJByte: ...

class RC2ParameterSpec(java.security.spec.AlgorithmParameterSpec):
    @typing.overload
    def __init__(self, effectiveKeyBits: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, effectiveKeyBits: int | java.jint | java.lang.Integer, iv: java.chaquopy.JavaArrayJByte, /) -> None: ...
    @typing.overload
    def __init__(self, effectiveKeyBits: int | java.jint | java.lang.Integer, iv: java.chaquopy.JavaArrayJByte, offset: int | java.jint | java.lang.Integer, /) -> None: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getEffectiveKeyBits(self) -> int: ...
    def getIV(self) -> java.chaquopy.JavaArrayJByte: ...
    def hashCode(self) -> int: ...

class RC5ParameterSpec(java.security.spec.AlgorithmParameterSpec):
    @typing.overload
    def __init__(self, version: int | java.jint | java.lang.Integer, rounds: int | java.jint | java.lang.Integer, wordSize: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, version: int | java.jint | java.lang.Integer, rounds: int | java.jint | java.lang.Integer, wordSize: int | java.jint | java.lang.Integer, iv: java.chaquopy.JavaArrayJByte, /) -> None: ...
    @typing.overload
    def __init__(self, version: int | java.jint | java.lang.Integer, rounds: int | java.jint | java.lang.Integer, wordSize: int | java.jint | java.lang.Integer, iv: java.chaquopy.JavaArrayJByte, offset: int | java.jint | java.lang.Integer, /) -> None: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getIV(self) -> java.chaquopy.JavaArrayJByte: ...
    def getRounds(self) -> int: ...
    def getVersion(self) -> int: ...
    def getWordSize(self) -> int: ...
    def hashCode(self) -> int: ...

class SecretKeySpec(java.security.spec.KeySpec, javax.crypto.SecretKey):
    @typing.overload
    def __init__(self, key: java.chaquopy.JavaArrayJByte, algorithm: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, key: java.chaquopy.JavaArrayJByte, offset: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, algorithm: str | java.lang.String, /) -> None: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getAlgorithm(self) -> str: ...
    def getEncoded(self) -> java.chaquopy.JavaArrayJByte: ...
    def getFormat(self) -> str: ...
    def hashCode(self) -> int: ...



import typing

import android.content
import android.net
import android.net.wifi
import android.net.wifi.p2p.nsd
import android.os
import java
import java.chaquopy
import java.lang
import java.net
import java.util
import java.util.concurrent
import java.util.function

class WifiP2pConfig(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[WifiP2pConfig]] = ...
    GROUP_CLIENT_IP_PROVISIONING_MODE_IPV4_DHCP: typing.ClassVar[int] = ...
    GROUP_CLIENT_IP_PROVISIONING_MODE_IPV6_LINK_LOCAL: typing.ClassVar[int] = ...
    GROUP_OWNER_BAND_2GHZ: typing.ClassVar[int] = ...
    GROUP_OWNER_BAND_5GHZ: typing.ClassVar[int] = ...
    GROUP_OWNER_BAND_6GHZ: typing.ClassVar[int] = ...
    GROUP_OWNER_BAND_AUTO: typing.ClassVar[int] = ...
    GROUP_OWNER_INTENT_AUTO: typing.ClassVar[int] = ...
    GROUP_OWNER_INTENT_MAX: typing.ClassVar[int] = ...
    GROUP_OWNER_INTENT_MIN: typing.ClassVar[int] = ...
    P2P_VERSION_1: typing.ClassVar[int] = ...
    P2P_VERSION_2: typing.ClassVar[int] = ...
    PCC_MODE_CONNECTION_TYPE_LEGACY_ONLY: typing.ClassVar[int] = ...
    PCC_MODE_CONNECTION_TYPE_LEGACY_OR_R2: typing.ClassVar[int] = ...
    PCC_MODE_CONNECTION_TYPE_R2_ONLY: typing.ClassVar[int] = ...
    deviceAddress: str = ...
    groupOwnerIntent: int = ...
    wps: android.net.wifi.WpsInfo = ...
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, source: WifiP2pConfig, /) -> None: ...
    def describeContents(self) -> int: ...
    def getGroupClientIpProvisioningMode(self) -> int: ...
    def getGroupOwnerBand(self) -> int: ...
    def getGroupOwnerVersion(self) -> int: ...
    def getNetworkId(self) -> int: ...
    def getNetworkName(self) -> str | None: ...
    def getPairingBootstrappingConfig(self) -> WifiP2pPairingBootstrappingConfig: ...
    def getPassphrase(self) -> str | None: ...
    def getPccModeConnectionType(self) -> int: ...
    def isAuthorizeConnectionFromPeerEnabled(self) -> bool: ...
    def setGroupOwnerVersion(self, version: int | java.jint | java.lang.Integer, /) -> None: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> WifiP2pConfig: ...
        def enablePersistentMode(self, persistent: bool | java.jboolean | java.lang.Boolean, /) -> WifiP2pConfig.Builder: ...
        def setAuthorizeConnectionFromPeerEnabled(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> WifiP2pConfig.Builder: ...
        def setDeviceAddress(self, deviceAddress: android.net.MacAddress, /) -> WifiP2pConfig.Builder: ...
        def setGroupClientIpProvisioningMode(self, groupClientIpProvisioningMode: int | java.jint | java.lang.Integer, /) -> WifiP2pConfig.Builder: ...
        def setGroupOperatingBand(self, band: int | java.jint | java.lang.Integer, /) -> WifiP2pConfig.Builder: ...
        def setGroupOperatingFrequency(self, frequency: int | java.jint | java.lang.Integer, /) -> WifiP2pConfig.Builder: ...
        def setNetworkName(self, networkName: str | java.lang.String, /) -> WifiP2pConfig.Builder: ...
        def setPairingBootstrappingConfig(self, config: WifiP2pPairingBootstrappingConfig, /) -> WifiP2pConfig.Builder: ...
        def setPassphrase(self, passphrase: str | java.lang.String, /) -> WifiP2pConfig.Builder: ...
        def setPccModeConnectionType(self, connectionType: int | java.jint | java.lang.Integer, /) -> WifiP2pConfig.Builder: ...

class WifiP2pDevice(android.os.Parcelable):
    AVAILABLE: typing.ClassVar[int] = ...
    CONNECTED: typing.ClassVar[int] = ...
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[WifiP2pDevice]] = ...
    FAILED: typing.ClassVar[int] = ...
    INVITED: typing.ClassVar[int] = ...
    UNAVAILABLE: typing.ClassVar[int] = ...
    deviceAddress: str = ...
    deviceName: str = ...
    primaryDeviceType: str = ...
    secondaryDeviceType: str = ...
    status: int = ...
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, source: WifiP2pDevice, /) -> None: ...
    def describeContents(self) -> int: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getIpAddress(self) -> java.net.InetAddress | None: ...
    def getVendorElements(self) -> java.util.List[android.net.wifi.ScanResult.InformationElement]: ...
    def getWfdInfo(self) -> WifiP2pWfdInfo | None: ...
    def hashCode(self) -> int: ...
    def isGroupOwner(self) -> bool: ...
    def isOpportunisticBootstrappingMethodSupported(self) -> bool: ...
    def isPassphraseDisplayBootstrappingMethodSupported(self) -> bool: ...
    def isPassphraseKeypadBootstrappingMethodSupported(self) -> bool: ...
    def isPinCodeDisplayBootstrappingMethodSupported(self) -> bool: ...
    def isPinCodeKeypadBootstrappingMethodSupported(self) -> bool: ...
    def isServiceDiscoveryCapable(self) -> bool: ...
    def toString(self) -> str: ...
    def update(self, device: WifiP2pDevice, /) -> None: ...
    def wpsDisplaySupported(self) -> bool: ...
    def wpsKeypadSupported(self) -> bool: ...
    def wpsPbcSupported(self) -> bool: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class WifiP2pDeviceList(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[WifiP2pDeviceList]] = ...
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, source: WifiP2pDeviceList, /) -> None: ...
    def describeContents(self) -> int: ...
    def get(self, deviceAddress: str | java.lang.String, /) -> WifiP2pDevice | None: ...
    def getDeviceList(self) -> java.util.Collection[WifiP2pDevice]: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class WifiP2pDirInfo(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[WifiP2pDirInfo]] = ...
    def __init__(self, macAddress: android.net.MacAddress, nonce: java.chaquopy.JavaArrayJByte, dirTag: java.chaquopy.JavaArrayJByte, /) -> None: ...
    def describeContents(self) -> int: ...
    def getDirTag(self) -> java.chaquopy.JavaArrayJByte: ...
    def getMacAddress(self) -> android.net.MacAddress: ...
    def getNonce(self) -> java.chaquopy.JavaArrayJByte: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class WifiP2pDiscoveryConfig(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[WifiP2pDiscoveryConfig]] = ...
    def describeContents(self) -> int: ...
    def getFrequencyMhz(self) -> int: ...
    def getScanType(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self, scanType: int | java.jint | java.lang.Integer, /) -> None: ...
        def build(self) -> WifiP2pDiscoveryConfig: ...
        def setFrequencyMhz(self, frequencyMhz: int | java.jint | java.lang.Integer, /) -> WifiP2pDiscoveryConfig.Builder: ...

class WifiP2pGroup(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[WifiP2pGroup]] = ...
    NETWORK_ID_PERSISTENT: typing.ClassVar[int] = ...
    NETWORK_ID_TEMPORARY: typing.ClassVar[int] = ...
    SECURITY_TYPE_UNKNOWN: typing.ClassVar[int] = ...
    SECURITY_TYPE_WPA2_PSK: typing.ClassVar[int] = ...
    SECURITY_TYPE_WPA3_COMPATIBILITY: typing.ClassVar[int] = ...
    SECURITY_TYPE_WPA3_SAE: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, source: WifiP2pGroup, /) -> None: ...
    def describeContents(self) -> int: ...
    def getClientList(self) -> java.util.Collection[WifiP2pDevice]: ...
    def getFrequency(self) -> int: ...
    def getGroupOwnerBssid(self) -> android.net.MacAddress: ...
    def getInterface(self) -> str: ...
    def getNetworkId(self) -> int: ...
    def getNetworkName(self) -> str: ...
    def getOwner(self) -> WifiP2pDevice: ...
    def getPassphrase(self) -> str: ...
    def getSecurityType(self) -> int: ...
    def isGroupOwner(self) -> bool: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class WifiP2pInfo(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[WifiP2pInfo]] = ...
    groupFormed: bool = ...
    groupOwnerAddress: java.net.InetAddress = ...
    isGroupOwner: bool = ...
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, source: WifiP2pInfo, /) -> None: ...
    def describeContents(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class WifiP2pManager(java.lang.Object):
    ACTION_WIFI_P2P_LISTEN_STATE_CHANGED: typing.ClassVar[str] = ...
    ACTION_WIFI_P2P_REQUEST_RESPONSE_CHANGED: typing.ClassVar[str] = ...
    BUSY: typing.ClassVar[int] = ...
    CONNECTION_REQUEST_ACCEPT: typing.ClassVar[int] = ...
    CONNECTION_REQUEST_DEFER_SHOW_PIN_TO_SERVICE: typing.ClassVar[int] = ...
    CONNECTION_REQUEST_DEFER_TO_SERVICE: typing.ClassVar[int] = ...
    CONNECTION_REQUEST_REJECT: typing.ClassVar[int] = ...
    ERROR: typing.ClassVar[int] = ...
    EXTRA_DISCOVERY_STATE: typing.ClassVar[str] = ...
    EXTRA_LISTEN_STATE: typing.ClassVar[str] = ...
    EXTRA_NETWORK_INFO: typing.ClassVar[str] = ...
    EXTRA_P2P_DEVICE_LIST: typing.ClassVar[str] = ...
    EXTRA_REQUEST_CONFIG: typing.ClassVar[str] = ...
    EXTRA_REQUEST_RESPONSE: typing.ClassVar[str] = ...
    EXTRA_WIFI_P2P_DEVICE: typing.ClassVar[str] = ...
    EXTRA_WIFI_P2P_GROUP: typing.ClassVar[str] = ...
    EXTRA_WIFI_P2P_INFO: typing.ClassVar[str] = ...
    EXTRA_WIFI_STATE: typing.ClassVar[str] = ...
    GROUP_CREATION_FAILURE_REASON_CONNECTION_CANCELLED: typing.ClassVar[int] = ...
    GROUP_CREATION_FAILURE_REASON_GROUP_REMOVED: typing.ClassVar[int] = ...
    GROUP_CREATION_FAILURE_REASON_INVITATION_FAILED: typing.ClassVar[int] = ...
    GROUP_CREATION_FAILURE_REASON_PROVISION_DISCOVERY_FAILED: typing.ClassVar[int] = ...
    GROUP_CREATION_FAILURE_REASON_TIMED_OUT: typing.ClassVar[int] = ...
    GROUP_CREATION_FAILURE_REASON_USER_REJECTED: typing.ClassVar[int] = ...
    NO_PERMISSION: typing.ClassVar[int] = ...
    NO_SERVICE_REQUESTS: typing.ClassVar[int] = ...
    P2P_UNSUPPORTED: typing.ClassVar[int] = ...
    WIFI_P2P_CONNECTION_CHANGED_ACTION: typing.ClassVar[str] = ...
    WIFI_P2P_DISCOVERY_CHANGED_ACTION: typing.ClassVar[str] = ...
    WIFI_P2P_DISCOVERY_STARTED: typing.ClassVar[int] = ...
    WIFI_P2P_DISCOVERY_STOPPED: typing.ClassVar[int] = ...
    WIFI_P2P_LISTEN_STARTED: typing.ClassVar[int] = ...
    WIFI_P2P_LISTEN_STOPPED: typing.ClassVar[int] = ...
    WIFI_P2P_PEERS_CHANGED_ACTION: typing.ClassVar[str] = ...
    WIFI_P2P_SCAN_FULL: typing.ClassVar[int] = ...
    WIFI_P2P_SCAN_SINGLE_FREQ: typing.ClassVar[int] = ...
    WIFI_P2P_SCAN_SOCIAL: typing.ClassVar[int] = ...
    WIFI_P2P_STATE_CHANGED_ACTION: typing.ClassVar[str] = ...
    WIFI_P2P_STATE_DISABLED: typing.ClassVar[int] = ...
    WIFI_P2P_STATE_ENABLED: typing.ClassVar[int] = ...
    WIFI_P2P_THIS_DEVICE_CHANGED_ACTION: typing.ClassVar[str] = ...
    def addExternalApprover(self, c: WifiP2pManager.Channel, deviceAddress: android.net.MacAddress, listener: WifiP2pManager.ExternalApproverRequestListener, /) -> None: ...
    def addLocalService(self, channel: WifiP2pManager.Channel, servInfo: android.net.wifi.p2p.nsd.WifiP2pServiceInfo, listener: WifiP2pManager.ActionListener, /) -> None: ...
    def addServiceRequest(self, channel: WifiP2pManager.Channel, req: android.net.wifi.p2p.nsd.WifiP2pServiceRequest, listener: WifiP2pManager.ActionListener, /) -> None: ...
    def cancelConnect(self, channel: WifiP2pManager.Channel, listener: WifiP2pManager.ActionListener, /) -> None: ...
    def clearLocalServices(self, channel: WifiP2pManager.Channel, listener: WifiP2pManager.ActionListener, /) -> None: ...
    def clearServiceRequests(self, channel: WifiP2pManager.Channel, listener: WifiP2pManager.ActionListener, /) -> None: ...
    def connect(self, channel: WifiP2pManager.Channel, config: WifiP2pConfig, listener: WifiP2pManager.ActionListener, /) -> None: ...
    @typing.overload
    def createGroup(self, channel: WifiP2pManager.Channel, listener: WifiP2pManager.ActionListener, /) -> None: ...
    @typing.overload
    def createGroup(self, channel: WifiP2pManager.Channel, config: WifiP2pConfig, listener: WifiP2pManager.ActionListener, /) -> None: ...
    def discoverPeers(self, channel: WifiP2pManager.Channel, listener: WifiP2pManager.ActionListener, /) -> None: ...
    def discoverPeersOnSocialChannels(self, channel: WifiP2pManager.Channel, listener: WifiP2pManager.ActionListener, /) -> None: ...
    def discoverPeersOnSpecificFrequency(self, channel: WifiP2pManager.Channel, frequencyMhz: int | java.jint | java.lang.Integer, listener: WifiP2pManager.ActionListener, /) -> None: ...
    def discoverServices(self, channel: WifiP2pManager.Channel, listener: WifiP2pManager.ActionListener, /) -> None: ...
    def discoverUsdBasedServices(self, channel: WifiP2pManager.Channel, config: WifiP2pUsdBasedServiceDiscoveryConfig, listener: WifiP2pManager.ActionListener, /) -> None: ...
    def getListenState(self, c: WifiP2pManager.Channel, executor: java.util.concurrent.Executor, resultsCallback: java.util.function.Consumer[java.lang.Integer], /) -> None: ...
    @staticmethod
    def getP2pMaxAllowedVendorElementsLengthBytes() -> int: ...
    def initialize(self, srcContext: android.content.Context, srcLooper: android.os.Looper, listener: WifiP2pManager.ChannelListener, /) -> WifiP2pManager.Channel: ...
    def isChannelConstrainedDiscoverySupported(self) -> bool: ...
    def isGroupClientRemovalSupported(self) -> bool: ...
    def isGroupOwnerIPv6LinkLocalAddressProvided(self) -> bool: ...
    def isPccModeSupported(self) -> bool: ...
    def isSetVendorElementsSupported(self) -> bool: ...
    def isWiFiDirectR2Supported(self) -> bool: ...
    def registerWifiP2pListener(self, executor: java.util.concurrent.Executor, listener: WifiP2pManager.WifiP2pListener, /) -> None: ...
    def removeClient(self, channel: WifiP2pManager.Channel, peerAddress: android.net.MacAddress, listener: WifiP2pManager.ActionListener, /) -> None: ...
    def removeExternalApprover(self, c: WifiP2pManager.Channel, deviceAddress: android.net.MacAddress, listener: WifiP2pManager.ActionListener, /) -> None: ...
    def removeGroup(self, channel: WifiP2pManager.Channel, listener: WifiP2pManager.ActionListener, /) -> None: ...
    def removeLocalService(self, channel: WifiP2pManager.Channel, servInfo: android.net.wifi.p2p.nsd.WifiP2pServiceInfo, listener: WifiP2pManager.ActionListener, /) -> None: ...
    def removeServiceRequest(self, channel: WifiP2pManager.Channel, req: android.net.wifi.p2p.nsd.WifiP2pServiceRequest, listener: WifiP2pManager.ActionListener, /) -> None: ...
    def requestConnectionInfo(self, channel: WifiP2pManager.Channel, listener: WifiP2pManager.ConnectionInfoListener, /) -> None: ...
    def requestDeviceInfo(self, c: WifiP2pManager.Channel, listener: WifiP2pManager.DeviceInfoListener, /) -> None: ...
    def requestDirInfo(self, c: WifiP2pManager.Channel, executor: java.util.concurrent.Executor, callback: android.os.OutcomeReceiver[WifiP2pDirInfo, java.lang.Exception], /) -> None: ...
    def requestDiscoveryState(self, c: WifiP2pManager.Channel, listener: WifiP2pManager.DiscoveryStateListener, /) -> None: ...
    def requestGroupInfo(self, channel: WifiP2pManager.Channel, listener: WifiP2pManager.GroupInfoListener, /) -> None: ...
    def requestNetworkInfo(self, c: WifiP2pManager.Channel, listener: WifiP2pManager.NetworkInfoListener, /) -> None: ...
    def requestP2pState(self, c: WifiP2pManager.Channel, listener: WifiP2pManager.P2pStateListener, /) -> None: ...
    def requestPeers(self, channel: WifiP2pManager.Channel, listener: WifiP2pManager.PeerListListener, /) -> None: ...
    @typing.overload
    def setConnectionRequestResult(self, c: WifiP2pManager.Channel, deviceAddress: android.net.MacAddress, result: int | java.jint | java.lang.Integer, listener: WifiP2pManager.ActionListener, /) -> None: ...
    @typing.overload
    def setConnectionRequestResult(self, c: WifiP2pManager.Channel, deviceAddress: android.net.MacAddress, result: int | java.jint | java.lang.Integer, pin: str | java.lang.String, listener: WifiP2pManager.ActionListener, /) -> None: ...
    def setDnsSdResponseListeners(self, channel: WifiP2pManager.Channel, servListener: WifiP2pManager.DnsSdServiceResponseListener, txtListener: WifiP2pManager.DnsSdTxtRecordListener, /) -> None: ...
    def setServiceResponseListener(self, channel: WifiP2pManager.Channel, listener: WifiP2pManager.ServiceResponseListener, /) -> None: ...
    def setUpnpServiceResponseListener(self, channel: WifiP2pManager.Channel, listener: WifiP2pManager.UpnpServiceResponseListener, /) -> None: ...
    def setVendorElements(self, c: WifiP2pManager.Channel, vendorElements: java.util.List[android.net.wifi.ScanResult.InformationElement], listener: WifiP2pManager.ActionListener, /) -> None: ...
    def setWfdInfo(self, channel: WifiP2pManager.Channel, wfdInfo: WifiP2pWfdInfo, listener: WifiP2pManager.ActionListener, /) -> None: ...
    def startListening(self, channel: WifiP2pManager.Channel, listener: WifiP2pManager.ActionListener, /) -> None: ...
    def startPeerDiscovery(self, channel: WifiP2pManager.Channel, config: WifiP2pDiscoveryConfig, listener: WifiP2pManager.ActionListener, /) -> None: ...
    def startUsdBasedLocalServiceAdvertisement(self, channel: WifiP2pManager.Channel, servInfo: android.net.wifi.p2p.nsd.WifiP2pServiceInfo, config: WifiP2pUsdBasedLocalServiceAdvertisementConfig, listener: WifiP2pManager.ActionListener, /) -> None: ...
    def stopListening(self, channel: WifiP2pManager.Channel, listener: WifiP2pManager.ActionListener, /) -> None: ...
    def stopPeerDiscovery(self, channel: WifiP2pManager.Channel, listener: WifiP2pManager.ActionListener, /) -> None: ...
    def unregisterWifiP2pListener(self, listener: WifiP2pManager.WifiP2pListener, /) -> None: ...
    def validateDirInfo(self, c: WifiP2pManager.Channel, dirInfo: WifiP2pDirInfo, executor: java.util.concurrent.Executor, callback: android.os.OutcomeReceiver[java.lang.Boolean, java.lang.Exception], /) -> None: ...

    class WifiP2pListener(java.lang.Object):
        def onDeviceConfigurationChanged(self, p2pDevice: WifiP2pDevice, /) -> None: ...
        def onDiscoveryStateChanged(self, state: int | java.jint | java.lang.Integer, /) -> None: ...
        def onFrequencyChanged(self, p2pInfo: WifiP2pInfo, p2pGroup: WifiP2pGroup, /) -> None: ...
        def onGroupCreated(self, p2pInfo: WifiP2pInfo, p2pGroup: WifiP2pGroup, /) -> None: ...
        def onGroupCreating(self) -> None: ...
        def onGroupCreationFailed(self, reason: int | java.jint | java.lang.Integer, /) -> None: ...
        def onGroupNegotiationRejectedByUser(self) -> None: ...
        def onGroupRemoved(self) -> None: ...
        def onListenStateChanged(self, state: int | java.jint | java.lang.Integer, /) -> None: ...
        def onP2pStateChanged(self, state: int | java.jint | java.lang.Integer, /) -> None: ...
        def onPeerClientDisconnected(self, p2pInfo: WifiP2pInfo, p2pGroup: WifiP2pGroup, /) -> None: ...
        def onPeerClientJoined(self, p2pInfo: WifiP2pInfo, p2pGroup: WifiP2pGroup, /) -> None: ...
        def onPeerListChanged(self, p2pDeviceList: WifiP2pDeviceList, /) -> None: ...

    class UpnpServiceResponseListener(java.lang.Object):
        def onUpnpServiceAvailable(self, arg1: java.util.List[java.lang.String], arg2: WifiP2pDevice, /) -> None: ...

    class ServiceResponseListener(java.lang.Object):
        def onServiceAvailable(self, arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJByte, arg3: WifiP2pDevice, /) -> None: ...
        def onUsdBasedServiceAvailable(self, srcDevice: WifiP2pDevice, usdResponseData: android.net.wifi.p2p.nsd.WifiP2pUsdBasedServiceResponse, /) -> None: ...

    class PeerListListener(java.lang.Object):
        def onPeersAvailable(self, arg1: WifiP2pDeviceList, /) -> None: ...

    class P2pStateListener(java.lang.Object):
        def onP2pStateAvailable(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...

    class NetworkInfoListener(java.lang.Object):
        def onNetworkInfoAvailable(self, arg1: android.net.NetworkInfo, /) -> None: ...

    class GroupInfoListener(java.lang.Object):
        def onGroupInfoAvailable(self, arg1: WifiP2pGroup, /) -> None: ...

    class ExternalApproverRequestListener(java.lang.Object):
        APPROVER_DETACH_REASON_CLOSE: typing.ClassVar[int] = ...
        APPROVER_DETACH_REASON_FAILURE: typing.ClassVar[int] = ...
        APPROVER_DETACH_REASON_REMOVE: typing.ClassVar[int] = ...
        APPROVER_DETACH_REASON_REPLACE: typing.ClassVar[int] = ...
        REQUEST_TYPE_INVITATION: typing.ClassVar[int] = ...
        REQUEST_TYPE_JOIN: typing.ClassVar[int] = ...
        REQUEST_TYPE_NEGOTIATION: typing.ClassVar[int] = ...
        def onAttached(self, arg1: android.net.MacAddress, /) -> None: ...
        def onConnectionRequested(self, arg1: int | java.jint | java.lang.Integer, arg2: WifiP2pConfig, arg3: WifiP2pDevice, /) -> None: ...
        def onDetached(self, arg1: android.net.MacAddress, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
        def onPinGenerated(self, arg1: android.net.MacAddress, arg2: str | java.lang.String, /) -> None: ...

    class DnsSdTxtRecordListener(java.lang.Object):
        def onDnsSdTxtRecordAvailable(self, arg1: str | java.lang.String, arg2: java.util.Map[java.lang.String, java.lang.String], arg3: WifiP2pDevice, /) -> None: ...

    class DnsSdServiceResponseListener(java.lang.Object):
        def onDnsSdServiceAvailable(self, arg1: str | java.lang.String, arg2: str | java.lang.String, arg3: WifiP2pDevice, /) -> None: ...

    class DiscoveryStateListener(java.lang.Object):
        def onDiscoveryStateAvailable(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...

    class DeviceInfoListener(java.lang.Object):
        def onDeviceInfoAvailable(self, arg1: WifiP2pDevice, /) -> None: ...

    class ConnectionInfoListener(java.lang.Object):
        def onConnectionInfoAvailable(self, arg1: WifiP2pInfo, /) -> None: ...

    class ChannelListener(java.lang.Object):
        def onChannelDisconnected(self) -> None: ...

    class Channel(java.lang.AutoCloseable):
        def close(self) -> None: ...
        def finalize(self) -> None: ...

    class ActionListener(java.lang.Object):
        def onFailure(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
        def onSuccess(self) -> None: ...

class WifiP2pPairingBootstrappingConfig(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[WifiP2pPairingBootstrappingConfig]] = ...
    PAIRING_BOOTSTRAPPING_METHOD_DISPLAY_PASSPHRASE: typing.ClassVar[int] = ...
    PAIRING_BOOTSTRAPPING_METHOD_DISPLAY_PINCODE: typing.ClassVar[int] = ...
    PAIRING_BOOTSTRAPPING_METHOD_KEYPAD_PASSPHRASE: typing.ClassVar[int] = ...
    PAIRING_BOOTSTRAPPING_METHOD_KEYPAD_PINCODE: typing.ClassVar[int] = ...
    PAIRING_BOOTSTRAPPING_METHOD_OPPORTUNISTIC: typing.ClassVar[int] = ...
    PAIRING_BOOTSTRAPPING_METHOD_OUT_OF_BAND: typing.ClassVar[int] = ...
    def __init__(self, method: int | java.jint | java.lang.Integer, password: str | java.lang.String, /) -> None: ...
    def describeContents(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class WifiP2pUsdBasedLocalServiceAdvertisementConfig(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[WifiP2pUsdBasedLocalServiceAdvertisementConfig]] = ...
    def describeContents(self) -> int: ...
    def getFrequencyMhz(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> WifiP2pUsdBasedLocalServiceAdvertisementConfig: ...
        def setFrequencyMhz(self, frequencyMhz: int | java.jint | java.lang.Integer, /) -> WifiP2pUsdBasedLocalServiceAdvertisementConfig.Builder: ...

class WifiP2pUsdBasedServiceDiscoveryConfig(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[WifiP2pUsdBasedServiceDiscoveryConfig]] = ...
    def describeContents(self) -> int: ...
    def getBand(self) -> int: ...
    def getFrequenciesMhz(self) -> java.chaquopy.JavaArrayJInt: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> WifiP2pUsdBasedServiceDiscoveryConfig: ...
        def setBand(self, band: int | java.jint | java.lang.Integer, /) -> WifiP2pUsdBasedServiceDiscoveryConfig.Builder: ...
        def setFrequenciesMhz(self, frequenciesMhz: java.chaquopy.JavaArrayJInt, /) -> WifiP2pUsdBasedServiceDiscoveryConfig.Builder: ...

class WifiP2pWfdInfo(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[WifiP2pWfdInfo]] = ...
    DEVICE_INFO_AUDIO_ONLY_SUPPORT_AT_SOURCE: typing.ClassVar[int] = ...
    DEVICE_INFO_AUDIO_UNSUPPORTED_AT_PRIMARY_SINK: typing.ClassVar[int] = ...
    DEVICE_INFO_CONTENT_PROTECTION_SUPPORT: typing.ClassVar[int] = ...
    DEVICE_INFO_COUPLED_SINK_SUPPORT_AT_SINK: typing.ClassVar[int] = ...
    DEVICE_INFO_COUPLED_SINK_SUPPORT_AT_SOURCE: typing.ClassVar[int] = ...
    DEVICE_INFO_DEVICE_TYPE_MASK: typing.ClassVar[int] = ...
    DEVICE_INFO_PREFERRED_CONNECTIVITY_MASK: typing.ClassVar[int] = ...
    DEVICE_INFO_SESSION_AVAILABLE_MASK: typing.ClassVar[int] = ...
    DEVICE_INFO_TDLS_PERSISTENT_GROUP: typing.ClassVar[int] = ...
    DEVICE_INFO_TDLS_PERSISTENT_GROUP_REINVOKE: typing.ClassVar[int] = ...
    DEVICE_INFO_TIME_SYNCHRONIZATION_SUPPORT: typing.ClassVar[int] = ...
    DEVICE_INFO_WFD_SERVICE_DISCOVERY_SUPPORT: typing.ClassVar[int] = ...
    DEVICE_TYPE_PRIMARY_SINK: typing.ClassVar[int] = ...
    DEVICE_TYPE_SECONDARY_SINK: typing.ClassVar[int] = ...
    DEVICE_TYPE_SOURCE_OR_PRIMARY_SINK: typing.ClassVar[int] = ...
    DEVICE_TYPE_WFD_SOURCE: typing.ClassVar[int] = ...
    PREFERRED_CONNECTIVITY_P2P: typing.ClassVar[int] = ...
    PREFERRED_CONNECTIVITY_TDLS: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, source: WifiP2pWfdInfo, /) -> None: ...
    def describeContents(self) -> int: ...
    def getControlPort(self) -> int: ...
    def getDeviceInfo(self) -> int: ...
    def getDeviceType(self) -> int: ...
    def getMaxThroughput(self) -> int: ...
    def getR2DeviceInfo(self) -> int: ...
    def getR2DeviceType(self) -> int: ...
    def isContentProtectionSupported(self) -> bool: ...
    def isCoupledSinkSupportedAtSink(self) -> bool: ...
    def isCoupledSinkSupportedAtSource(self) -> bool: ...
    def isEnabled(self) -> bool: ...
    def isR2Supported(self) -> bool: ...
    def isSessionAvailable(self) -> bool: ...
    def setContentProtectionSupported(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setControlPort(self, port: int | java.jint | java.lang.Integer, /) -> None: ...
    def setCoupledSinkSupportAtSink(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setCoupledSinkSupportAtSource(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setDeviceType(self, deviceType: int | java.jint | java.lang.Integer, /) -> bool: ...
    def setEnabled(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setMaxThroughput(self, maxThroughput: int | java.jint | java.lang.Integer, /) -> None: ...
    def setR2DeviceType(self, deviceType: int | java.jint | java.lang.Integer, /) -> bool: ...
    def setSessionAvailable(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...



import typing

import android.animation
import android.content
import android.graphics
import android.util
import android.view
import java
import java.lang
import java.util

class AccelerateDecelerateInterpolator(BaseInterpolator):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    def getInterpolation(self, input: float | java.jfloat | java.lang.Float, /) -> float: ...

class AccelerateInterpolator(BaseInterpolator):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, factor: float | java.jfloat | java.lang.Float, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    def getInterpolation(self, input: float | java.jfloat | java.lang.Float, /) -> float: ...

class AlphaAnimation(Animation):
    @typing.overload
    def __init__(self, fromAlpha: float | java.jfloat | java.lang.Float, toAlpha: float | java.jfloat | java.lang.Float, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    def applyTransformation(self, interpolatedTime: float | java.jfloat | java.lang.Float, t: Transformation, /) -> None: ...
    def willChangeBounds(self) -> bool: ...
    def willChangeTransformationMatrix(self) -> bool: ...

class Animation(java.lang.Cloneable):
    ABSOLUTE: typing.ClassVar[int] = ...
    INFINITE: typing.ClassVar[int] = ...
    RELATIVE_TO_PARENT: typing.ClassVar[int] = ...
    RELATIVE_TO_SELF: typing.ClassVar[int] = ...
    RESTART: typing.ClassVar[int] = ...
    REVERSE: typing.ClassVar[int] = ...
    START_ON_FIRST_FRAME: typing.ClassVar[int] = ...
    ZORDER_BOTTOM: typing.ClassVar[int] = ...
    ZORDER_NORMAL: typing.ClassVar[int] = ...
    ZORDER_TOP: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    def applyTransformation(self, interpolatedTime: float | java.jfloat | java.lang.Float, t: Transformation, /) -> None: ...
    def cancel(self) -> None: ...
    def clone(self) -> Animation: ...
    def computeDurationHint(self) -> int: ...
    def ensureInterpolator(self) -> None: ...
    def finalize(self) -> None: ...
    def getBackdropColor(self) -> int: ...
    def getBackgroundColor(self) -> int: ...
    def getDetachWallpaper(self) -> bool: ...
    def getDuration(self) -> int: ...
    def getFillAfter(self) -> bool: ...
    def getFillBefore(self) -> bool: ...
    def getInterpolator(self) -> Interpolator: ...
    def getRepeatCount(self) -> int: ...
    def getRepeatMode(self) -> int: ...
    def getScaleFactor(self) -> float: ...
    def getShowBackdrop(self) -> bool: ...
    def getStartOffset(self) -> int: ...
    def getStartTime(self) -> int: ...
    @typing.overload
    def getTransformation(self, currentTime: int | java.jlong | java.lang.Long, outTransformation: Transformation, /) -> bool: ...
    @typing.overload
    def getTransformation(self, currentTime: int | java.jlong | java.lang.Long, outTransformation: Transformation, scale: float | java.jfloat | java.lang.Float, /) -> bool: ...
    def getZAdjustment(self) -> int: ...
    def hasEnded(self) -> bool: ...
    def hasStarted(self) -> bool: ...
    def initialize(self, width: int | java.jint | java.lang.Integer, height: int | java.jint | java.lang.Integer, parentWidth: int | java.jint | java.lang.Integer, parentHeight: int | java.jint | java.lang.Integer, /) -> None: ...
    def isFillEnabled(self) -> bool: ...
    def isInitialized(self) -> bool: ...
    def reset(self) -> None: ...
    def resolveSize(self, type: int | java.jint | java.lang.Integer, value: float | java.jfloat | java.lang.Float, size: int | java.jint | java.lang.Integer, parentSize: int | java.jint | java.lang.Integer, /) -> float: ...
    def restrictDuration(self, durationMillis: int | java.jlong | java.lang.Long, /) -> None: ...
    def scaleCurrentDuration(self, scale: float | java.jfloat | java.lang.Float, /) -> None: ...
    def setAnimationListener(self, listener: Animation.AnimationListener, /) -> None: ...
    def setBackdropColor(self, backdropColor: int | java.jint | java.lang.Integer, /) -> None: ...
    def setBackgroundColor(self, bg: int | java.jint | java.lang.Integer, /) -> None: ...
    def setDetachWallpaper(self, detachWallpaper: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setDuration(self, durationMillis: int | java.jlong | java.lang.Long, /) -> None: ...
    def setFillAfter(self, fillAfter: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setFillBefore(self, fillBefore: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setFillEnabled(self, fillEnabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def setInterpolator(self, i: Interpolator, /) -> None: ...
    @typing.overload
    def setInterpolator(self, context: android.content.Context, resID: int | java.jint | java.lang.Integer, /) -> None: ...
    def setRepeatCount(self, repeatCount: int | java.jint | java.lang.Integer, /) -> None: ...
    def setRepeatMode(self, repeatMode: int | java.jint | java.lang.Integer, /) -> None: ...
    def setShowBackdrop(self, showBackdrop: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setStartOffset(self, startOffset: int | java.jlong | java.lang.Long, /) -> None: ...
    def setStartTime(self, startTimeMillis: int | java.jlong | java.lang.Long, /) -> None: ...
    def setZAdjustment(self, zAdjustment: int | java.jint | java.lang.Integer, /) -> None: ...
    def start(self) -> None: ...
    def startNow(self) -> None: ...
    def willChangeBounds(self) -> bool: ...
    def willChangeTransformationMatrix(self) -> bool: ...

    class Description(java.lang.Object):
        type: int = ...
        value: float = ...
        def __init__(self) -> None: ...

    class AnimationListener(java.lang.Object):
        def onAnimationEnd(self, arg1: Animation, /) -> None: ...
        def onAnimationRepeat(self, arg1: Animation, /) -> None: ...
        def onAnimationStart(self, arg1: Animation, /) -> None: ...

class AnimationSet(Animation):
    @typing.overload
    def __init__(self, shareInterpolator: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    def addAnimation(self, a: Animation, /) -> None: ...
    def clone(self) -> AnimationSet: ...
    def computeDurationHint(self) -> int: ...
    def getAnimations(self) -> java.util.List[Animation]: ...
    def getDuration(self) -> int: ...
    def getStartTime(self) -> int: ...
    def getTransformation(self, currentTime: int | java.jlong | java.lang.Long, t: Transformation, /) -> bool: ...
    def initialize(self, width: int | java.jint | java.lang.Integer, height: int | java.jint | java.lang.Integer, parentWidth: int | java.jint | java.lang.Integer, parentHeight: int | java.jint | java.lang.Integer, /) -> None: ...
    def reset(self) -> None: ...
    def restrictDuration(self, durationMillis: int | java.jlong | java.lang.Long, /) -> None: ...
    def scaleCurrentDuration(self, scale: float | java.jfloat | java.lang.Float, /) -> None: ...
    def setDuration(self, durationMillis: int | java.jlong | java.lang.Long, /) -> None: ...
    def setFillAfter(self, fillAfter: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setFillBefore(self, fillBefore: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setRepeatMode(self, repeatMode: int | java.jint | java.lang.Integer, /) -> None: ...
    def setStartOffset(self, startOffset: int | java.jlong | java.lang.Long, /) -> None: ...
    def setStartTime(self, startTimeMillis: int | java.jlong | java.lang.Long, /) -> None: ...
    def willChangeBounds(self) -> bool: ...
    def willChangeTransformationMatrix(self) -> bool: ...

class AnimationUtils(java.lang.Object):
    def __init__(self) -> None: ...
    @staticmethod
    def currentAnimationTimeMillis() -> int: ...
    @staticmethod
    def loadAnimation(context: android.content.Context, id: int | java.jint | java.lang.Integer, /) -> Animation: ...
    @staticmethod
    def loadInterpolator(context: android.content.Context, id: int | java.jint | java.lang.Integer, /) -> Interpolator: ...
    @staticmethod
    def loadLayoutAnimation(context: android.content.Context, id: int | java.jint | java.lang.Integer, /) -> LayoutAnimationController: ...
    @staticmethod
    def makeInAnimation(c: android.content.Context, fromLeft: bool | java.jboolean | java.lang.Boolean, /) -> Animation: ...
    @staticmethod
    def makeInChildBottomAnimation(c: android.content.Context, /) -> Animation: ...
    @staticmethod
    def makeOutAnimation(c: android.content.Context, toRight: bool | java.jboolean | java.lang.Boolean, /) -> Animation: ...

class AnticipateInterpolator(BaseInterpolator):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, tension: float | java.jfloat | java.lang.Float, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    def getInterpolation(self, t: float | java.jfloat | java.lang.Float, /) -> float: ...

class AnticipateOvershootInterpolator(BaseInterpolator):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, tension: float | java.jfloat | java.lang.Float, /) -> None: ...
    @typing.overload
    def __init__(self, tension: float | java.jfloat | java.lang.Float, extraTension: float | java.jfloat | java.lang.Float, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    def getInterpolation(self, t: float | java.jfloat | java.lang.Float, /) -> float: ...

class BaseInterpolator(Interpolator):
    def __init__(self) -> None: ...

class BounceInterpolator(BaseInterpolator):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    def getInterpolation(self, t: float | java.jfloat | java.lang.Float, /) -> float: ...

class CycleInterpolator(BaseInterpolator):
    @typing.overload
    def __init__(self, cycles: float | java.jfloat | java.lang.Float, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    def getInterpolation(self, input: float | java.jfloat | java.lang.Float, /) -> float: ...

class DecelerateInterpolator(BaseInterpolator):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, factor: float | java.jfloat | java.lang.Float, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    def getInterpolation(self, input: float | java.jfloat | java.lang.Float, /) -> float: ...

class GridLayoutAnimationController(LayoutAnimationController):
    DIRECTION_BOTTOM_TO_TOP: typing.ClassVar[int] = ...
    DIRECTION_HORIZONTAL_MASK: typing.ClassVar[int] = ...
    DIRECTION_LEFT_TO_RIGHT: typing.ClassVar[int] = ...
    DIRECTION_RIGHT_TO_LEFT: typing.ClassVar[int] = ...
    DIRECTION_TOP_TO_BOTTOM: typing.ClassVar[int] = ...
    DIRECTION_VERTICAL_MASK: typing.ClassVar[int] = ...
    PRIORITY_COLUMN: typing.ClassVar[int] = ...
    PRIORITY_NONE: typing.ClassVar[int] = ...
    PRIORITY_ROW: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self, animation: Animation, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, animation: Animation, columnDelay: float | java.jfloat | java.lang.Float, rowDelay: float | java.jfloat | java.lang.Float, /) -> None: ...
    def getColumnDelay(self) -> float: ...
    def getDelayForView(self, view: android.view.View, /) -> int: ...
    def getDirection(self) -> int: ...
    def getDirectionPriority(self) -> int: ...
    def getRowDelay(self) -> float: ...
    def setColumnDelay(self, columnDelay: float | java.jfloat | java.lang.Float, /) -> None: ...
    def setDirection(self, direction: int | java.jint | java.lang.Integer, /) -> None: ...
    def setDirectionPriority(self, directionPriority: int | java.jint | java.lang.Integer, /) -> None: ...
    def setRowDelay(self, rowDelay: float | java.jfloat | java.lang.Float, /) -> None: ...
    def willOverlap(self) -> bool: ...

    class AnimationParameters(LayoutAnimationController.AnimationParameters):
        column: int = ...
        columnsCount: int = ...
        row: int = ...
        rowsCount: int = ...
        def __init__(self) -> None: ...

class Interpolator(android.animation.TimeInterpolator): ...

class LayoutAnimationController(java.lang.Object):
    ORDER_NORMAL: typing.ClassVar[int] = ...
    ORDER_RANDOM: typing.ClassVar[int] = ...
    ORDER_REVERSE: typing.ClassVar[int] = ...
    mAnimation: Animation = ...
    mInterpolator: Interpolator = ...
    mRandomizer: java.util.Random = ...
    @typing.overload
    def __init__(self, animation: Animation, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, animation: Animation, delay: float | java.jfloat | java.lang.Float, /) -> None: ...
    def getAnimation(self) -> Animation: ...
    def getAnimationForView(self, view: android.view.View, /) -> Animation: ...
    def getDelay(self) -> float: ...
    def getDelayForView(self, view: android.view.View, /) -> int: ...
    def getInterpolator(self) -> Interpolator: ...
    def getOrder(self) -> int: ...
    def getTransformedIndex(self, params: LayoutAnimationController.AnimationParameters, /) -> int: ...
    def isDone(self) -> bool: ...
    @typing.overload
    def setAnimation(self, animation: Animation, /) -> None: ...
    @typing.overload
    def setAnimation(self, context: android.content.Context, resourceID: int | java.jint | java.lang.Integer, /) -> None: ...
    def setDelay(self, delay: float | java.jfloat | java.lang.Float, /) -> None: ...
    @typing.overload
    def setInterpolator(self, interpolator: Interpolator, /) -> None: ...
    @typing.overload
    def setInterpolator(self, context: android.content.Context, resourceID: int | java.jint | java.lang.Integer, /) -> None: ...
    def setOrder(self, order: int | java.jint | java.lang.Integer, /) -> None: ...
    def start(self) -> None: ...
    def willOverlap(self) -> bool: ...

    class AnimationParameters(java.lang.Object):
        count: int = ...
        index: int = ...
        def __init__(self) -> None: ...

class LinearInterpolator(BaseInterpolator):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    def getInterpolation(self, input: float | java.jfloat | java.lang.Float, /) -> float: ...

class OvershootInterpolator(BaseInterpolator):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, tension: float | java.jfloat | java.lang.Float, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    def getInterpolation(self, t: float | java.jfloat | java.lang.Float, /) -> float: ...

class PathInterpolator(BaseInterpolator):
    @typing.overload
    def __init__(self, path: android.graphics.Path, /) -> None: ...
    @typing.overload
    def __init__(self, controlX: float | java.jfloat | java.lang.Float, controlY: float | java.jfloat | java.lang.Float, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, controlX1: float | java.jfloat | java.lang.Float, controlY1: float | java.jfloat | java.lang.Float, controlX2: float | java.jfloat | java.lang.Float, controlY2: float | java.jfloat | java.lang.Float, /) -> None: ...
    def getInterpolation(self, t: float | java.jfloat | java.lang.Float, /) -> float: ...

class RotateAnimation(Animation):
    @typing.overload
    def __init__(self, fromDegrees: float | java.jfloat | java.lang.Float, toDegrees: float | java.jfloat | java.lang.Float, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, fromDegrees: float | java.jfloat | java.lang.Float, toDegrees: float | java.jfloat | java.lang.Float, pivotX: float | java.jfloat | java.lang.Float, pivotY: float | java.jfloat | java.lang.Float, /) -> None: ...
    @typing.overload
    def __init__(self, fromDegrees: float | java.jfloat | java.lang.Float, toDegrees: float | java.jfloat | java.lang.Float, pivotXType: int | java.jint | java.lang.Integer, pivotXValue: float | java.jfloat | java.lang.Float, pivotYType: int | java.jint | java.lang.Integer, pivotYValue: float | java.jfloat | java.lang.Float, /) -> None: ...
    def applyTransformation(self, interpolatedTime: float | java.jfloat | java.lang.Float, t: Transformation, /) -> None: ...
    def initialize(self, width: int | java.jint | java.lang.Integer, height: int | java.jint | java.lang.Integer, parentWidth: int | java.jint | java.lang.Integer, parentHeight: int | java.jint | java.lang.Integer, /) -> None: ...

class ScaleAnimation(Animation):
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, fromX: float | java.jfloat | java.lang.Float, toX: float | java.jfloat | java.lang.Float, fromY: float | java.jfloat | java.lang.Float, toY: float | java.jfloat | java.lang.Float, /) -> None: ...
    @typing.overload
    def __init__(self, fromX: float | java.jfloat | java.lang.Float, toX: float | java.jfloat | java.lang.Float, fromY: float | java.jfloat | java.lang.Float, toY: float | java.jfloat | java.lang.Float, pivotX: float | java.jfloat | java.lang.Float, pivotY: float | java.jfloat | java.lang.Float, /) -> None: ...
    @typing.overload
    def __init__(self, fromX: float | java.jfloat | java.lang.Float, toX: float | java.jfloat | java.lang.Float, fromY: float | java.jfloat | java.lang.Float, toY: float | java.jfloat | java.lang.Float, pivotXType: int | java.jint | java.lang.Integer, pivotXValue: float | java.jfloat | java.lang.Float, pivotYType: int | java.jint | java.lang.Integer, pivotYValue: float | java.jfloat | java.lang.Float, /) -> None: ...
    def applyTransformation(self, interpolatedTime: float | java.jfloat | java.lang.Float, t: Transformation, /) -> None: ...
    def initialize(self, width: int | java.jint | java.lang.Integer, height: int | java.jint | java.lang.Integer, parentWidth: int | java.jint | java.lang.Integer, parentHeight: int | java.jint | java.lang.Integer, /) -> None: ...

class Transformation(java.lang.Object):
    TYPE_ALPHA: typing.ClassVar[int] = ...
    TYPE_BOTH: typing.ClassVar[int] = ...
    TYPE_IDENTITY: typing.ClassVar[int] = ...
    TYPE_MATRIX: typing.ClassVar[int] = ...
    mAlpha: float = ...
    mMatrix: android.graphics.Matrix = ...
    mTransformationType: int = ...
    def __init__(self) -> None: ...
    def clear(self) -> None: ...
    def compose(self, t: Transformation, /) -> None: ...
    def getAlpha(self) -> float: ...
    def getMatrix(self) -> android.graphics.Matrix: ...
    def getTransformationType(self) -> int: ...
    def set(self, t: Transformation, /) -> None: ...
    def setAlpha(self, alpha: float | java.jfloat | java.lang.Float, /) -> None: ...
    def setTransformationType(self, transformationType: int | java.jint | java.lang.Integer, /) -> None: ...
    def toShortString(self) -> str: ...
    def toString(self) -> str: ...

class TranslateAnimation(Animation):
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, fromXDelta: float | java.jfloat | java.lang.Float, toXDelta: float | java.jfloat | java.lang.Float, fromYDelta: float | java.jfloat | java.lang.Float, toYDelta: float | java.jfloat | java.lang.Float, /) -> None: ...
    @typing.overload
    def __init__(self, fromXType: int | java.jint | java.lang.Integer, fromXValue: float | java.jfloat | java.lang.Float, toXType: int | java.jint | java.lang.Integer, toXValue: float | java.jfloat | java.lang.Float, fromYType: int | java.jint | java.lang.Integer, fromYValue: float | java.jfloat | java.lang.Float, toYType: int | java.jint | java.lang.Integer, toYValue: float | java.jfloat | java.lang.Float, /) -> None: ...
    def applyTransformation(self, interpolatedTime: float | java.jfloat | java.lang.Float, t: Transformation, /) -> None: ...
    def initialize(self, width: int | java.jint | java.lang.Integer, height: int | java.jint | java.lang.Integer, parentWidth: int | java.jint | java.lang.Integer, parentHeight: int | java.jint | java.lang.Integer, /) -> None: ...



import typing

import java
import java.chaquopy
import java.lang
import java.math
import java.security
import java.security.spec
import java.util

class DSAKey(java.lang.Object):
    def getParams(self) -> DSAParams: ...

class DSAKeyPairGenerator(java.lang.Object):
    @typing.overload
    def initialize(self, arg1: DSAParams, arg2: java.security.SecureRandom, /) -> None: ...
    @typing.overload
    def initialize(self, arg1: int | java.jint | java.lang.Integer, arg2: bool | java.jboolean | java.lang.Boolean, arg3: java.security.SecureRandom, /) -> None: ...

class DSAParams(java.lang.Object):
    def getG(self) -> java.math.BigInteger: ...
    def getP(self) -> java.math.BigInteger: ...
    def getQ(self) -> java.math.BigInteger: ...

class DSAPrivateKey(DSAKey, java.security.PrivateKey):
    serialVersionUID: typing.ClassVar[int] = ...
    def getX(self) -> java.math.BigInteger: ...

class DSAPublicKey(DSAKey, java.security.PublicKey):
    serialVersionUID: typing.ClassVar[int] = ...
    def getY(self) -> java.math.BigInteger: ...

class ECKey(java.lang.Object):
    def getParams(self) -> java.security.spec.ECParameterSpec: ...

class ECPrivateKey(ECKey, java.security.PrivateKey):
    serialVersionUID: typing.ClassVar[int] = ...
    def getS(self) -> java.math.BigInteger: ...

class ECPublicKey(ECKey, java.security.PublicKey):
    serialVersionUID: typing.ClassVar[int] = ...
    def getW(self) -> java.security.spec.ECPoint: ...

class EdECKey(java.lang.Object):
    def getParams(self) -> java.security.spec.NamedParameterSpec: ...

class EdECPrivateKey(EdECKey, java.security.PrivateKey):
    def getBytes(self) -> java.util.Optional[java.chaquopy.JavaArrayJByte]: ...

class EdECPublicKey(EdECKey, java.security.PublicKey):
    def getPoint(self) -> java.security.spec.EdECPoint: ...

class RSAKey(java.lang.Object):
    def getModulus(self) -> java.math.BigInteger: ...
    def getParams(self) -> java.security.spec.AlgorithmParameterSpec: ...

class RSAMultiPrimePrivateCrtKey(RSAPrivateKey):
    serialVersionUID: typing.ClassVar[int] = ...
    def getCrtCoefficient(self) -> java.math.BigInteger: ...
    def getOtherPrimeInfo(self) -> java.chaquopy.JavaArray[java.security.spec.RSAOtherPrimeInfo]: ...
    def getPrimeExponentP(self) -> java.math.BigInteger: ...
    def getPrimeExponentQ(self) -> java.math.BigInteger: ...
    def getPrimeP(self) -> java.math.BigInteger: ...
    def getPrimeQ(self) -> java.math.BigInteger: ...
    def getPublicExponent(self) -> java.math.BigInteger: ...

class RSAPrivateCrtKey(RSAPrivateKey):
    serialVersionUID: typing.ClassVar[int] = ...
    def getCrtCoefficient(self) -> java.math.BigInteger: ...
    def getPrimeExponentP(self) -> java.math.BigInteger: ...
    def getPrimeExponentQ(self) -> java.math.BigInteger: ...
    def getPrimeP(self) -> java.math.BigInteger: ...
    def getPrimeQ(self) -> java.math.BigInteger: ...
    def getPublicExponent(self) -> java.math.BigInteger: ...

class RSAPrivateKey(RSAKey, java.security.PrivateKey):
    serialVersionUID: typing.ClassVar[int] = ...
    def getPrivateExponent(self) -> java.math.BigInteger: ...

class RSAPublicKey(RSAKey, java.security.PublicKey):
    serialVersionUID: typing.ClassVar[int] = ...
    def getPublicExponent(self) -> java.math.BigInteger: ...

class XECKey(java.lang.Object):
    def getParams(self) -> java.security.spec.AlgorithmParameterSpec: ...

class XECPrivateKey(XECKey, java.security.PrivateKey):
    def getScalar(self) -> java.util.Optional[java.chaquopy.JavaArrayJByte]: ...

class XECPublicKey(XECKey, java.security.PublicKey):
    def getU(self) -> java.math.BigInteger: ...



import typing

import android.graphics
import android.hardware.camera2
import android.os
import android.util
import android.view
import java
import java.chaquopy
import java.lang
import java.util
import java.util.concurrent

class BlackLevelPattern(java.lang.Object):
    COUNT: typing.ClassVar[int] = ...
    def __init__(self, offsets: java.chaquopy.JavaArrayJInt, /) -> None: ...
    def copyTo(self, destination: java.chaquopy.JavaArrayJInt, offset: int | java.jint | java.lang.Integer, /) -> None: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getOffsetForIndex(self, column: int | java.jint | java.lang.Integer, row: int | java.jint | java.lang.Integer, /) -> int: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...

class Capability(java.lang.Object):
    def __init__(self, mode: int | java.jint | java.lang.Integer, maxStreamingSize: android.util.Size, zoomRatioRange: android.util.Range[java.lang.Float], /) -> None: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getMaxStreamingSize(self) -> android.util.Size: ...
    def getMode(self) -> int: ...
    def getZoomRatioRange(self) -> android.util.Range[java.lang.Float]: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...

class ColorSpaceProfiles(java.lang.Object):
    UNSPECIFIED: typing.ClassVar[int] = ...
    def __init__(self, elements: java.chaquopy.JavaArrayJLong, /) -> None: ...
    def getSupportedColorSpaces(self, imageFormat: int | java.jint | java.lang.Integer, /) -> java.util.Set[android.graphics.ColorSpace.Named]: ...
    def getSupportedColorSpacesForDynamicRange(self, imageFormat: int | java.jint | java.lang.Integer, dynamicRangeProfile: int | java.jlong | java.lang.Long, /) -> java.util.Set[android.graphics.ColorSpace.Named]: ...
    def getSupportedDynamicRangeProfiles(self, colorSpace: android.graphics.ColorSpace.Named, imageFormat: int | java.jint | java.lang.Integer, /) -> java.util.Set[java.lang.Long]: ...
    def getSupportedImageFormatsForColorSpace(self, colorSpace: android.graphics.ColorSpace.Named, /) -> java.util.Set[java.lang.Integer]: ...

class ColorSpaceTransform(java.lang.Object):
    @typing.overload
    def __init__(self, elements: java.chaquopy.JavaArrayJInt, /) -> None: ...
    @typing.overload
    def __init__(self, elements: java.chaquopy.JavaArray[android.util.Rational], /) -> None: ...
    @typing.overload
    def copyElements(self, destination: java.chaquopy.JavaArrayJInt, offset: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def copyElements(self, destination: java.chaquopy.JavaArray[android.util.Rational], offset: int | java.jint | java.lang.Integer, /) -> None: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getElement(self, column: int | java.jint | java.lang.Integer, row: int | java.jint | java.lang.Integer, /) -> android.util.Rational: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...

class DeviceStateSensorOrientationMap(java.lang.Object):
    FOLDED: typing.ClassVar[int] = ...
    NORMAL: typing.ClassVar[int] = ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getSensorOrientation(self, deviceState: int | java.jlong | java.lang.Long, /) -> int: ...
    def hashCode(self) -> int: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def addOrientationForState(self, deviceState: int | java.jlong | java.lang.Long, angle: int | java.jlong | java.lang.Long, /) -> DeviceStateSensorOrientationMap.Builder: ...
        def build(self) -> DeviceStateSensorOrientationMap: ...

class DynamicRangeProfiles(java.lang.Object):
    DOLBY_VISION_10B_HDR_OEM: typing.ClassVar[int] = ...
    DOLBY_VISION_10B_HDR_OEM_PO: typing.ClassVar[int] = ...
    DOLBY_VISION_10B_HDR_REF: typing.ClassVar[int] = ...
    DOLBY_VISION_10B_HDR_REF_PO: typing.ClassVar[int] = ...
    DOLBY_VISION_8B_HDR_OEM: typing.ClassVar[int] = ...
    DOLBY_VISION_8B_HDR_OEM_PO: typing.ClassVar[int] = ...
    DOLBY_VISION_8B_HDR_REF: typing.ClassVar[int] = ...
    DOLBY_VISION_8B_HDR_REF_PO: typing.ClassVar[int] = ...
    HDR10: typing.ClassVar[int] = ...
    HDR10_PLUS: typing.ClassVar[int] = ...
    HLG10: typing.ClassVar[int] = ...
    PUBLIC_MAX: typing.ClassVar[int] = ...
    STANDARD: typing.ClassVar[int] = ...
    def __init__(self, elements: java.chaquopy.JavaArrayJLong, /) -> None: ...
    def getProfileCaptureRequestConstraints(self, profile: int | java.jlong | java.lang.Long, /) -> java.util.Set[java.lang.Long]: ...
    def getSupportedProfiles(self) -> java.util.Set[java.lang.Long]: ...
    def isExtraLatencyPresent(self, profile: int | java.jlong | java.lang.Long, /) -> bool: ...

class ExtensionSessionConfiguration(java.lang.Object):
    def __init__(self, extension: int | java.jint | java.lang.Integer, outputs: java.util.List[OutputConfiguration], executor: java.util.concurrent.Executor, listener: android.hardware.camera2.CameraExtensionSession.StateCallback, /) -> None: ...
    def clearColorSpace(self) -> None: ...
    def getColorSpace(self) -> android.graphics.ColorSpace | None: ...
    def getExecutor(self) -> java.util.concurrent.Executor: ...
    def getExtension(self) -> int: ...
    def getOutputConfigurations(self) -> java.util.List[OutputConfiguration]: ...
    def getPostviewOutputConfiguration(self) -> OutputConfiguration | None: ...
    def getStateCallback(self) -> android.hardware.camera2.CameraExtensionSession.StateCallback: ...
    def setColorSpace(self, colorSpace: android.graphics.ColorSpace.Named, /) -> None: ...
    def setPostviewOutputConfiguration(self, postviewOutput: OutputConfiguration, /) -> None: ...

class Face(java.lang.Object):
    ID_UNSUPPORTED: typing.ClassVar[int] = ...
    SCORE_MAX: typing.ClassVar[int] = ...
    SCORE_MIN: typing.ClassVar[int] = ...
    def getBounds(self) -> android.graphics.Rect: ...
    def getId(self) -> int: ...
    def getLeftEyePosition(self) -> android.graphics.Point: ...
    def getMouthPosition(self) -> android.graphics.Point: ...
    def getRightEyePosition(self) -> android.graphics.Point: ...
    def getScore(self) -> int: ...
    def toString(self) -> str: ...

    class Builder(java.lang.Object):
        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, current: Face, /) -> None: ...
        def build(self) -> Face: ...
        def setBounds(self, bounds: android.graphics.Rect, /) -> Face.Builder: ...
        def setId(self, id: int | java.jint | java.lang.Integer, /) -> Face.Builder: ...
        def setLeftEyePosition(self, leftEyePosition: android.graphics.Point, /) -> Face.Builder: ...
        def setMouthPosition(self, mouthPosition: android.graphics.Point, /) -> Face.Builder: ...
        def setRightEyePosition(self, rightEyePosition: android.graphics.Point, /) -> Face.Builder: ...
        def setScore(self, score: int | java.jint | java.lang.Integer, /) -> Face.Builder: ...

class InputConfiguration(java.lang.Object):
    @typing.overload
    def __init__(self, multiResolutionInputs: java.util.Collection[MultiResolutionStreamInfo], format: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, width: int | java.jint | java.lang.Integer, height: int | java.jint | java.lang.Integer, format: int | java.jint | java.lang.Integer, /) -> None: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getFormat(self) -> int: ...
    def getHeight(self) -> int: ...
    def getWidth(self) -> int: ...
    def hashCode(self) -> int: ...
    def isMultiResolution(self) -> bool: ...
    def toString(self) -> str: ...

class LensIntrinsicsSample(java.lang.Object):
    def __init__(self, timestampNs: int | java.jlong | java.lang.Long, lensIntrinsics: java.chaquopy.JavaArrayJFloat, /) -> None: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getLensIntrinsics(self) -> java.chaquopy.JavaArrayJFloat: ...
    def getTimestampNanos(self) -> int: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...

class LensShadingMap(java.lang.Object):
    MINIMUM_GAIN_FACTOR: typing.ClassVar[float] = ...
    def copyGainFactors(self, destination: java.chaquopy.JavaArrayJFloat, offset: int | java.jint | java.lang.Integer, /) -> None: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getColumnCount(self) -> int: ...
    def getGainFactor(self, colorChannel: int | java.jint | java.lang.Integer, column: int | java.jint | java.lang.Integer, row: int | java.jint | java.lang.Integer, /) -> float: ...
    def getGainFactorCount(self) -> int: ...
    def getGainFactorVector(self, column: int | java.jint | java.lang.Integer, row: int | java.jint | java.lang.Integer, /) -> RggbChannelVector: ...
    def getRowCount(self) -> int: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...

class MandatoryStreamCombination(java.lang.Object):
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getDescription(self) -> java.lang.CharSequence: ...
    def getStreamsInformation(self) -> java.util.List[MandatoryStreamCombination.MandatoryStreamInformation]: ...
    def hashCode(self) -> int: ...
    def isReprocessable(self) -> bool: ...

    class MandatoryStreamInformation(java.lang.Object):
        def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
        def get10BitFormat(self) -> int: ...
        def getAvailableSizes(self) -> java.util.List[android.util.Size]: ...
        def getFormat(self) -> int: ...
        def getStreamUseCase(self) -> int: ...
        def hashCode(self) -> int: ...
        def is10BitCapable(self) -> bool: ...
        def isInput(self) -> bool: ...
        def isMaximumSize(self) -> bool: ...
        def isUltraHighResolution(self) -> bool: ...

class MeteringRectangle(java.lang.Object):
    METERING_WEIGHT_DONT_CARE: typing.ClassVar[int] = ...
    METERING_WEIGHT_MAX: typing.ClassVar[int] = ...
    METERING_WEIGHT_MIN: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self, rect: android.graphics.Rect, meteringWeight: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, xy: android.graphics.Point, dimensions: android.util.Size, meteringWeight: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, x: int | java.jint | java.lang.Integer, y: int | java.jint | java.lang.Integer, width: int | java.jint | java.lang.Integer, height: int | java.jint | java.lang.Integer, meteringWeight: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def equals(self, other: MeteringRectangle, /) -> bool: ...
    @typing.overload
    def equals(self, other: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getHeight(self) -> int: ...
    def getMeteringWeight(self) -> int: ...
    def getRect(self) -> android.graphics.Rect: ...
    def getSize(self) -> android.util.Size: ...
    def getUpperLeftPoint(self) -> android.graphics.Point: ...
    def getWidth(self) -> int: ...
    def getX(self) -> int: ...
    def getY(self) -> int: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...

class MultiResolutionStreamConfigurationMap(java.lang.Object):
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getInputFormats(self) -> java.chaquopy.JavaArrayJInt: ...
    def getInputInfo(self, format: int | java.jint | java.lang.Integer, /) -> java.util.Collection[MultiResolutionStreamInfo]: ...
    def getOutputFormats(self) -> java.chaquopy.JavaArrayJInt: ...
    def getOutputInfo(self, format: int | java.jint | java.lang.Integer, /) -> java.util.Collection[MultiResolutionStreamInfo]: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...

class MultiResolutionStreamInfo(java.lang.Object):
    def __init__(self, streamWidth: int | java.jint | java.lang.Integer, streamHeight: int | java.jint | java.lang.Integer, physicalCameraId: str | java.lang.String, /) -> None: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getHeight(self) -> int: ...
    def getPhysicalCameraId(self) -> str: ...
    def getWidth(self) -> int: ...
    def hashCode(self) -> int: ...

class OisSample(java.lang.Object):
    def __init__(self, timestamp: int | java.jlong | java.lang.Long, xShift: float | java.jfloat | java.lang.Float, yShift: float | java.jfloat | java.lang.Float, /) -> None: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getTimestamp(self) -> int: ...
    def getXshift(self) -> float: ...
    def getYshift(self) -> float: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...

class OutputConfiguration(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[OutputConfiguration]] = ...
    MIRROR_MODE_AUTO: typing.ClassVar[int] = ...
    MIRROR_MODE_H: typing.ClassVar[int] = ...
    MIRROR_MODE_NONE: typing.ClassVar[int] = ...
    MIRROR_MODE_V: typing.ClassVar[int] = ...
    SURFACE_GROUP_ID_NONE: typing.ClassVar[int] = ...
    TIMESTAMP_BASE_CHOREOGRAPHER_SYNCED: typing.ClassVar[int] = ...
    TIMESTAMP_BASE_DEFAULT: typing.ClassVar[int] = ...
    TIMESTAMP_BASE_MONOTONIC: typing.ClassVar[int] = ...
    TIMESTAMP_BASE_REALTIME: typing.ClassVar[int] = ...
    TIMESTAMP_BASE_SENSOR: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self, surface: android.view.Surface, /) -> None: ...
    @typing.overload
    def __init__(self, format: int | java.jint | java.lang.Integer, surfaceSize: android.util.Size, /) -> None: ...
    @typing.overload
    def __init__(self, surfaceGroupId: int | java.jint | java.lang.Integer, surface: android.view.Surface, /) -> None: ...
    @typing.overload
    def __init__(self, surfaceSize: android.util.Size, klass: typing.Type[java.lang.Object], /) -> None: ...
    @typing.overload
    def __init__(self, surfaceGroupId: int | java.jint | java.lang.Integer, format: int | java.jint | java.lang.Integer, surfaceSize: android.util.Size, /) -> None: ...
    @typing.overload
    def __init__(self, format: int | java.jint | java.lang.Integer, surfaceSize: android.util.Size, usage: int | java.jlong | java.lang.Long, /) -> None: ...
    @typing.overload
    def __init__(self, surfaceGroupId: int | java.jint | java.lang.Integer, format: int | java.jint | java.lang.Integer, surfaceSize: android.util.Size, usage: int | java.jlong | java.lang.Long, /) -> None: ...
    def addSensorPixelModeUsed(self, sensorPixelModeUsed: int | java.jint | java.lang.Integer, /) -> None: ...
    def addSurface(self, surface: android.view.Surface, /) -> None: ...
    @typing.overload
    @staticmethod
    def createInstancesForMultiResolutionOutput(multiResolutionImageReader: android.hardware.camera2.MultiResolutionImageReader, /) -> java.util.Collection[OutputConfiguration]: ...
    @typing.overload
    @staticmethod
    def createInstancesForMultiResolutionOutput(streams: java.util.Collection[MultiResolutionStreamInfo], format: int | java.jint | java.lang.Integer, /) -> java.util.List[OutputConfiguration]: ...
    def describeContents(self) -> int: ...
    def enableSurfaceSharing(self) -> None: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getDynamicRangeProfile(self) -> int: ...
    def getMaxSharedSurfaceCount(self) -> int: ...
    @typing.overload
    def getMirrorMode(self) -> int: ...
    @typing.overload
    def getMirrorMode(self, surface: android.view.Surface, /) -> int: ...
    def getStreamUseCase(self) -> int: ...
    def getSurface(self) -> android.view.Surface | None: ...
    def getSurfaceGroupId(self) -> int: ...
    def getSurfaces(self) -> java.util.List[android.view.Surface]: ...
    def getTimestampBase(self) -> int: ...
    def hashCode(self) -> int: ...
    def isReadoutTimestampEnabled(self) -> bool: ...
    def removeSensorPixelModeUsed(self, sensorPixelModeUsed: int | java.jint | java.lang.Integer, /) -> None: ...
    def removeSurface(self, surface: android.view.Surface, /) -> None: ...
    def setDynamicRangeProfile(self, profile: int | java.jlong | java.lang.Long, /) -> None: ...
    @typing.overload
    def setMirrorMode(self, mirrorMode: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setMirrorMode(self, surface: android.view.Surface, mirrorMode: int | java.jint | java.lang.Integer, /) -> None: ...
    def setPhysicalCameraId(self, physicalCameraId: str | java.lang.String, /) -> None: ...
    def setReadoutTimestampEnabled(self, on: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setStreamUseCase(self, streamUseCase: int | java.jlong | java.lang.Long, /) -> None: ...
    @staticmethod
    def setSurfacesForMultiResolutionOutput(outputConfigurations: java.util.Collection[OutputConfiguration], multiResolutionImageReader: android.hardware.camera2.MultiResolutionImageReader, /) -> None: ...
    def setTimestampBase(self, timestampBase: int | java.jint | java.lang.Integer, /) -> None: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class RecommendedStreamConfigurationMap(java.lang.Object):
    USECASE_10BIT_OUTPUT: typing.ClassVar[int] = ...
    USECASE_LOW_LATENCY_SNAPSHOT: typing.ClassVar[int] = ...
    USECASE_PREVIEW: typing.ClassVar[int] = ...
    USECASE_RAW: typing.ClassVar[int] = ...
    USECASE_RECORD: typing.ClassVar[int] = ...
    USECASE_SNAPSHOT: typing.ClassVar[int] = ...
    USECASE_VIDEO_SNAPSHOT: typing.ClassVar[int] = ...
    USECASE_ZSL: typing.ClassVar[int] = ...
    def getHighResolutionOutputSizes(self, format: int | java.jint | java.lang.Integer, /) -> java.util.Set[android.util.Size] | None: ...
    def getHighSpeedVideoFpsRanges(self) -> java.util.Set[android.util.Range[java.lang.Integer]] | None: ...
    def getHighSpeedVideoFpsRangesFor(self, size: android.util.Size, /) -> java.util.Set[android.util.Range[java.lang.Integer]] | None: ...
    def getHighSpeedVideoSizes(self) -> java.util.Set[android.util.Size] | None: ...
    def getHighSpeedVideoSizesFor(self, fpsRange: android.util.Range[java.lang.Integer], /) -> java.util.Set[android.util.Size] | None: ...
    def getInputFormats(self) -> java.util.Set[java.lang.Integer] | None: ...
    def getInputSizes(self, format: int | java.jint | java.lang.Integer, /) -> java.util.Set[android.util.Size] | None: ...
    def getOutputFormats(self) -> java.util.Set[java.lang.Integer]: ...
    @typing.overload
    def getOutputMinFrameDuration(self, format: int | java.jint | java.lang.Integer, size: android.util.Size, /) -> int: ...
    @typing.overload
    def getOutputMinFrameDuration(self, klass: typing.Type[java.lang.Object], size: android.util.Size, /) -> int: ...
    @typing.overload
    def getOutputSizes(self, format: int | java.jint | java.lang.Integer, /) -> java.util.Set[android.util.Size] | None: ...
    @typing.overload
    def getOutputSizes(self, klass: typing.Type[java.lang.Object], /) -> java.util.Set[android.util.Size] | None: ...
    @typing.overload
    def getOutputStallDuration(self, format: int | java.jint | java.lang.Integer, size: android.util.Size, /) -> int: ...
    @typing.overload
    def getOutputStallDuration(self, klass: typing.Type[java.lang.Object], size: android.util.Size, /) -> int: ...
    def getRecommendedUseCase(self) -> int: ...
    def getValidOutputFormatsForInput(self, inputFormat: int | java.jint | java.lang.Integer, /) -> java.util.Set[java.lang.Integer] | None: ...
    @typing.overload
    def isOutputSupportedFor(self, format: int | java.jint | java.lang.Integer, /) -> bool: ...
    @typing.overload
    def isOutputSupportedFor(self, surface: android.view.Surface, /) -> bool: ...

class RggbChannelVector(java.lang.Object):
    BLUE: typing.ClassVar[int] = ...
    COUNT: typing.ClassVar[int] = ...
    GREEN_EVEN: typing.ClassVar[int] = ...
    GREEN_ODD: typing.ClassVar[int] = ...
    RED: typing.ClassVar[int] = ...
    def __init__(self, red: float | java.jfloat | java.lang.Float, greenEven: float | java.jfloat | java.lang.Float, greenOdd: float | java.jfloat | java.lang.Float, blue: float | java.jfloat | java.lang.Float, /) -> None: ...
    def copyTo(self, destination: java.chaquopy.JavaArrayJFloat, offset: int | java.jint | java.lang.Integer, /) -> None: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getBlue(self) -> float: ...
    def getComponent(self, colorChannel: int | java.jint | java.lang.Integer, /) -> float: ...
    def getGreenEven(self) -> float: ...
    def getGreenOdd(self) -> float: ...
    def getRed(self) -> float: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...

class SessionConfiguration(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[SessionConfiguration]] = ...
    SESSION_HIGH_SPEED: typing.ClassVar[int] = ...
    SESSION_REGULAR: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self, sessionType: int | java.jint | java.lang.Integer, outputs: java.util.List[OutputConfiguration], /) -> None: ...
    @typing.overload
    def __init__(self, sessionType: int | java.jint | java.lang.Integer, outputs: java.util.List[OutputConfiguration], executor: java.util.concurrent.Executor, cb: android.hardware.camera2.CameraCaptureSession.StateCallback, /) -> None: ...
    def clearColorSpace(self) -> None: ...
    def describeContents(self) -> int: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getColorSpace(self) -> android.graphics.ColorSpace | None: ...
    def getExecutor(self) -> java.util.concurrent.Executor: ...
    def getInputConfiguration(self) -> InputConfiguration: ...
    def getOutputConfigurations(self) -> java.util.List[OutputConfiguration]: ...
    def getSessionParameters(self) -> android.hardware.camera2.CaptureRequest: ...
    def getSessionType(self) -> int: ...
    def getStateCallback(self) -> android.hardware.camera2.CameraCaptureSession.StateCallback: ...
    def hashCode(self) -> int: ...
    def setColorSpace(self, colorSpace: android.graphics.ColorSpace.Named, /) -> None: ...
    def setInputConfiguration(self, input: InputConfiguration, /) -> None: ...
    def setSessionParameters(self, params: android.hardware.camera2.CaptureRequest, /) -> None: ...
    def setStateCallback(self, executor: java.util.concurrent.Executor, cb: android.hardware.camera2.CameraCaptureSession.StateCallback, /) -> None: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class StreamConfigurationMap(java.lang.Object):
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getHighResolutionOutputSizes(self, format: int | java.jint | java.lang.Integer, /) -> java.chaquopy.JavaArray[android.util.Size]: ...
    def getHighSpeedVideoFpsRanges(self) -> java.chaquopy.JavaArray[android.util.Range[java.lang.Integer]]: ...
    def getHighSpeedVideoFpsRangesFor(self, size: android.util.Size, /) -> java.chaquopy.JavaArray[android.util.Range[java.lang.Integer]]: ...
    def getHighSpeedVideoSizes(self) -> java.chaquopy.JavaArray[android.util.Size]: ...
    def getHighSpeedVideoSizesFor(self, fpsRange: android.util.Range[java.lang.Integer], /) -> java.chaquopy.JavaArray[android.util.Size]: ...
    def getInputFormats(self) -> java.chaquopy.JavaArrayJInt: ...
    def getInputSizes(self, format: int | java.jint | java.lang.Integer, /) -> java.chaquopy.JavaArray[android.util.Size]: ...
    def getOutputFormats(self) -> java.chaquopy.JavaArrayJInt: ...
    @typing.overload
    def getOutputMinFrameDuration(self, format: int | java.jint | java.lang.Integer, size: android.util.Size, /) -> int: ...
    @typing.overload
    def getOutputMinFrameDuration(self, klass: typing.Type[java.lang.Object], size: android.util.Size, /) -> int: ...
    @typing.overload
    def getOutputSizes(self, format: int | java.jint | java.lang.Integer, /) -> java.chaquopy.JavaArray[android.util.Size]: ...
    @typing.overload
    def getOutputSizes(self, klass: typing.Type[java.lang.Object], /) -> java.chaquopy.JavaArray[android.util.Size]: ...
    @typing.overload
    def getOutputStallDuration(self, format: int | java.jint | java.lang.Integer, size: android.util.Size, /) -> int: ...
    @typing.overload
    def getOutputStallDuration(self, klass: typing.Type[java.lang.Object], size: android.util.Size, /) -> int: ...
    def getValidOutputFormatsForInput(self, inputFormat: int | java.jint | java.lang.Integer, /) -> java.chaquopy.JavaArrayJInt: ...
    def hashCode(self) -> int: ...
    @typing.overload
    def isOutputSupportedFor(self, format: int | java.jint | java.lang.Integer, /) -> bool: ...
    @typing.overload
    def isOutputSupportedFor(self, surface: android.view.Surface, /) -> bool: ...
    @typing.overload
    @staticmethod
    def isOutputSupportedFor(klass: typing.Type[java.lang.Object], /) -> bool: ...
    def toString(self) -> str: ...

class TonemapCurve(java.lang.Object):
    CHANNEL_BLUE: typing.ClassVar[int] = ...
    CHANNEL_GREEN: typing.ClassVar[int] = ...
    CHANNEL_RED: typing.ClassVar[int] = ...
    LEVEL_BLACK: typing.ClassVar[float] = ...
    LEVEL_WHITE: typing.ClassVar[float] = ...
    POINT_SIZE: typing.ClassVar[int] = ...
    def __init__(self, red: java.chaquopy.JavaArrayJFloat, green: java.chaquopy.JavaArrayJFloat, blue: java.chaquopy.JavaArrayJFloat, /) -> None: ...
    def copyColorCurve(self, colorChannel: int | java.jint | java.lang.Integer, destination: java.chaquopy.JavaArrayJFloat, offset: int | java.jint | java.lang.Integer, /) -> None: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getPoint(self, colorChannel: int | java.jint | java.lang.Integer, index: int | java.jint | java.lang.Integer, /) -> android.graphics.PointF: ...
    def getPointCount(self, colorChannel: int | java.jint | java.lang.Integer, /) -> int: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...



import typing

import java
import java.chaquopy
import java.io
import java.lang
import java.net
import java.nio
import java.nio.channels.spi
import java.nio.charset
import java.nio.file
import java.nio.file.attribute
import java.util
import java.util.concurrent
import java.util.function

class AcceptPendingException(java.lang.IllegalStateException):
    def __init__(self) -> None: ...

class AlreadyBoundException(java.lang.IllegalStateException):
    def __init__(self) -> None: ...

class AlreadyConnectedException(java.lang.IllegalStateException):
    def __init__(self) -> None: ...

class AsynchronousByteChannel(AsynchronousChannel):
    _read_1__A = typing.TypeVar('_read_1__A')  # <A>
    @typing.overload
    def read(self, arg1: java.nio.ByteBuffer, /) -> java.util.concurrent.Future[java.lang.Integer]: ...
    @typing.overload
    def read(self, arg1: java.nio.ByteBuffer, arg2: _read_1__A, arg3: CompletionHandler[java.lang.Integer, _read_1__A], /) -> None: ...
    _write_1__A = typing.TypeVar('_write_1__A')  # <A>
    @typing.overload
    def write(self, arg1: java.nio.ByteBuffer, /) -> java.util.concurrent.Future[java.lang.Integer]: ...
    @typing.overload
    def write(self, arg1: java.nio.ByteBuffer, arg2: _write_1__A, arg3: CompletionHandler[java.lang.Integer, _write_1__A], /) -> None: ...

class AsynchronousChannel(Channel):
    def close(self) -> None: ...

class AsynchronousChannelGroup(java.lang.Object):
    def __init__(self, provider: java.nio.channels.spi.AsynchronousChannelProvider, /) -> None: ...
    def awaitTermination(self, arg1: int | java.jlong | java.lang.Long, arg2: java.util.concurrent.TimeUnit, /) -> bool: ...
    def isShutdown(self) -> bool: ...
    def isTerminated(self) -> bool: ...
    def provider(self) -> java.nio.channels.spi.AsynchronousChannelProvider: ...
    def shutdown(self) -> None: ...
    def shutdownNow(self) -> None: ...
    @staticmethod
    def withCachedThreadPool(executor: java.util.concurrent.ExecutorService, initialSize: int | java.jint | java.lang.Integer, /) -> AsynchronousChannelGroup: ...
    @staticmethod
    def withFixedThreadPool(nThreads: int | java.jint | java.lang.Integer, threadFactory: java.util.concurrent.ThreadFactory, /) -> AsynchronousChannelGroup: ...
    @staticmethod
    def withThreadPool(executor: java.util.concurrent.ExecutorService, /) -> AsynchronousChannelGroup: ...

class AsynchronousCloseException(ClosedChannelException):
    def __init__(self) -> None: ...

class AsynchronousFileChannel(AsynchronousChannel):
    def __init__(self) -> None: ...
    def force(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    _lock_1__A = typing.TypeVar('_lock_1__A')  # <A>
    _lock_3__A = typing.TypeVar('_lock_3__A')  # <A>
    @typing.overload
    def lock(self) -> java.util.concurrent.Future[FileLock]: ...
    @typing.overload
    def lock(self, attachment: _lock_1__A, handler: CompletionHandler[FileLock, _lock_1__A], /) -> None: ...
    @typing.overload
    def lock(self, arg1: int | java.jlong | java.lang.Long, arg2: int | java.jlong | java.lang.Long, arg3: bool | java.jboolean | java.lang.Boolean, /) -> java.util.concurrent.Future[FileLock]: ...
    @typing.overload
    def lock(self, arg1: int | java.jlong | java.lang.Long, arg2: int | java.jlong | java.lang.Long, arg3: bool | java.jboolean | java.lang.Boolean, arg4: _lock_3__A, arg5: CompletionHandler[FileLock, _lock_3__A], /) -> None: ...
    @typing.overload
    @staticmethod
    def open(file: java.nio.file.Path, /, *options: java.nio.file.OpenOption) -> AsynchronousFileChannel: ...
    @typing.overload
    @staticmethod
    def open(file: java.nio.file.Path, options: java.util.Set[java.nio.file.OpenOption], executor: java.util.concurrent.ExecutorService, /, *attrs: java.nio.file.attribute.FileAttribute[java.lang.Object]) -> AsynchronousFileChannel: ...
    _read_1__A = typing.TypeVar('_read_1__A')  # <A>
    @typing.overload
    def read(self, arg1: java.nio.ByteBuffer, arg2: int | java.jlong | java.lang.Long, /) -> java.util.concurrent.Future[java.lang.Integer]: ...
    @typing.overload
    def read(self, arg1: java.nio.ByteBuffer, arg2: int | java.jlong | java.lang.Long, arg3: _read_1__A, arg4: CompletionHandler[java.lang.Integer, _read_1__A], /) -> None: ...
    def size(self) -> int: ...
    def truncate(self, arg1: int | java.jlong | java.lang.Long, /) -> AsynchronousFileChannel: ...
    @typing.overload
    def tryLock(self) -> FileLock: ...
    @typing.overload
    def tryLock(self, arg1: int | java.jlong | java.lang.Long, arg2: int | java.jlong | java.lang.Long, arg3: bool | java.jboolean | java.lang.Boolean, /) -> FileLock: ...
    _write_1__A = typing.TypeVar('_write_1__A')  # <A>
    @typing.overload
    def write(self, arg1: java.nio.ByteBuffer, arg2: int | java.jlong | java.lang.Long, /) -> java.util.concurrent.Future[java.lang.Integer]: ...
    @typing.overload
    def write(self, arg1: java.nio.ByteBuffer, arg2: int | java.jlong | java.lang.Long, arg3: _write_1__A, arg4: CompletionHandler[java.lang.Integer, _write_1__A], /) -> None: ...

class AsynchronousServerSocketChannel(AsynchronousChannel, NetworkChannel):
    def __init__(self, provider: java.nio.channels.spi.AsynchronousChannelProvider, /) -> None: ...
    _accept_1__A = typing.TypeVar('_accept_1__A')  # <A>
    @typing.overload
    def accept(self) -> java.util.concurrent.Future[AsynchronousSocketChannel]: ...
    @typing.overload
    def accept(self, arg1: _accept_1__A, arg2: CompletionHandler[AsynchronousSocketChannel, _accept_1__A], /) -> None: ...
    @typing.overload
    def bind(self, local: java.net.SocketAddress, /) -> AsynchronousServerSocketChannel: ...
    @typing.overload
    def bind(self, arg1: java.net.SocketAddress, arg2: int | java.jint | java.lang.Integer, /) -> AsynchronousServerSocketChannel: ...
    def getLocalAddress(self) -> java.net.SocketAddress: ...
    @typing.overload
    @staticmethod
    def open() -> AsynchronousServerSocketChannel: ...
    @typing.overload
    @staticmethod
    def open(group: AsynchronousChannelGroup, /) -> AsynchronousServerSocketChannel: ...
    def provider(self) -> java.nio.channels.spi.AsynchronousChannelProvider: ...
    _setOption__T = typing.TypeVar('_setOption__T')  # <T>
    def setOption(self, arg1: java.net.SocketOption[_setOption__T], arg2: _setOption__T, /) -> AsynchronousServerSocketChannel: ...

class AsynchronousSocketChannel(AsynchronousByteChannel, NetworkChannel):
    def __init__(self, provider: java.nio.channels.spi.AsynchronousChannelProvider, /) -> None: ...
    def bind(self, arg1: java.net.SocketAddress, /) -> AsynchronousSocketChannel: ...
    _connect_1__A = typing.TypeVar('_connect_1__A')  # <A>
    @typing.overload
    def connect(self, arg1: java.net.SocketAddress, /) -> java.util.concurrent.Future[java.lang.Void]: ...
    @typing.overload
    def connect(self, arg1: java.net.SocketAddress, arg2: _connect_1__A, arg3: CompletionHandler[java.lang.Void, _connect_1__A], /) -> None: ...
    def getLocalAddress(self) -> java.net.SocketAddress: ...
    def getRemoteAddress(self) -> java.net.SocketAddress: ...
    @typing.overload
    @staticmethod
    def open() -> AsynchronousSocketChannel: ...
    @typing.overload
    @staticmethod
    def open(group: AsynchronousChannelGroup, /) -> AsynchronousSocketChannel: ...
    def provider(self) -> java.nio.channels.spi.AsynchronousChannelProvider: ...
    _read_1__A = typing.TypeVar('_read_1__A')  # <A>
    _read_2__A = typing.TypeVar('_read_2__A')  # <A>
    _read_3__A = typing.TypeVar('_read_3__A')  # <A>
    @typing.overload
    def read(self, arg1: java.nio.ByteBuffer, /) -> java.util.concurrent.Future[java.lang.Integer]: ...
    @typing.overload
    def read(self, dst: java.nio.ByteBuffer, attachment: _read_1__A, handler: CompletionHandler[java.lang.Integer, _read_1__A], /) -> None: ...
    @typing.overload
    def read(self, arg1: java.nio.ByteBuffer, arg2: int | java.jlong | java.lang.Long, arg3: java.util.concurrent.TimeUnit, arg4: _read_2__A, arg5: CompletionHandler[java.lang.Integer, _read_2__A], /) -> None: ...
    @typing.overload
    def read(self, arg1: java.chaquopy.JavaArray[java.nio.ByteBuffer], arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jlong | java.lang.Long, arg5: java.util.concurrent.TimeUnit, arg6: _read_3__A, arg7: CompletionHandler[java.lang.Long, _read_3__A], /) -> None: ...
    _setOption__T = typing.TypeVar('_setOption__T')  # <T>
    def setOption(self, arg1: java.net.SocketOption[_setOption__T], arg2: _setOption__T, /) -> AsynchronousSocketChannel: ...
    def shutdownInput(self) -> AsynchronousSocketChannel: ...
    def shutdownOutput(self) -> AsynchronousSocketChannel: ...
    _write_1__A = typing.TypeVar('_write_1__A')  # <A>
    _write_2__A = typing.TypeVar('_write_2__A')  # <A>
    _write_3__A = typing.TypeVar('_write_3__A')  # <A>
    @typing.overload
    def write(self, arg1: java.nio.ByteBuffer, /) -> java.util.concurrent.Future[java.lang.Integer]: ...
    @typing.overload
    def write(self, src: java.nio.ByteBuffer, attachment: _write_1__A, handler: CompletionHandler[java.lang.Integer, _write_1__A], /) -> None: ...
    @typing.overload
    def write(self, arg1: java.nio.ByteBuffer, arg2: int | java.jlong | java.lang.Long, arg3: java.util.concurrent.TimeUnit, arg4: _write_2__A, arg5: CompletionHandler[java.lang.Integer, _write_2__A], /) -> None: ...
    @typing.overload
    def write(self, arg1: java.chaquopy.JavaArray[java.nio.ByteBuffer], arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jlong | java.lang.Long, arg5: java.util.concurrent.TimeUnit, arg6: _write_3__A, arg7: CompletionHandler[java.lang.Long, _write_3__A], /) -> None: ...

class ByteChannel(ReadableByteChannel, WritableByteChannel): ...

class CancelledKeyException(java.lang.IllegalStateException):
    def __init__(self) -> None: ...

class Channel(java.io.Closeable):
    def close(self) -> None: ...
    def isOpen(self) -> bool: ...

class Channels(java.lang.Object):
    @typing.overload
    @staticmethod
    def newChannel(in_: java.io.InputStream, /) -> ReadableByteChannel: ...
    @typing.overload
    @staticmethod
    def newChannel(out: java.io.OutputStream, /) -> WritableByteChannel: ...
    @typing.overload
    @staticmethod
    def newInputStream(ch: AsynchronousByteChannel, /) -> java.io.InputStream: ...
    @typing.overload
    @staticmethod
    def newInputStream(ch: ReadableByteChannel, /) -> java.io.InputStream: ...
    @typing.overload
    @staticmethod
    def newOutputStream(ch: AsynchronousByteChannel, /) -> java.io.OutputStream: ...
    @typing.overload
    @staticmethod
    def newOutputStream(ch: WritableByteChannel, /) -> java.io.OutputStream: ...
    @typing.overload
    @staticmethod
    def newReader(ch: ReadableByteChannel, csName: str | java.lang.String, /) -> java.io.Reader: ...
    @typing.overload
    @staticmethod
    def newReader(ch: ReadableByteChannel, charset: java.nio.charset.Charset, /) -> java.io.Reader: ...
    @typing.overload
    @staticmethod
    def newReader(ch: ReadableByteChannel, dec: java.nio.charset.CharsetDecoder, minBufferCap: int | java.jint | java.lang.Integer, /) -> java.io.Reader: ...
    @typing.overload
    @staticmethod
    def newWriter(ch: WritableByteChannel, csName: str | java.lang.String, /) -> java.io.Writer: ...
    @typing.overload
    @staticmethod
    def newWriter(ch: WritableByteChannel, charset: java.nio.charset.Charset, /) -> java.io.Writer: ...
    @typing.overload
    @staticmethod
    def newWriter(ch: WritableByteChannel, enc: java.nio.charset.CharsetEncoder, minBufferCap: int | java.jint | java.lang.Integer, /) -> java.io.Writer: ...

class ClosedByInterruptException(AsynchronousCloseException):
    def __init__(self) -> None: ...

class ClosedChannelException(java.io.IOException):
    def __init__(self) -> None: ...

class ClosedSelectorException(java.lang.IllegalStateException):
    def __init__(self) -> None: ...

_CompletionHandler__V = typing.TypeVar('_CompletionHandler__V')  # <V>
_CompletionHandler__A = typing.TypeVar('_CompletionHandler__A')  # <A>
class CompletionHandler(java.lang.Object, typing.Generic[_CompletionHandler__V, _CompletionHandler__A]):
    def completed(self, arg1: _CompletionHandler__V, arg2: _CompletionHandler__A, /) -> None: ...
    def failed(self, arg1: java.lang.Throwable, arg2: _CompletionHandler__A, /) -> None: ...

class ConnectionPendingException(java.lang.IllegalStateException):
    def __init__(self) -> None: ...

class DatagramChannel(ByteChannel, GatheringByteChannel, MulticastChannel, ScatteringByteChannel, java.nio.channels.spi.AbstractSelectableChannel):
    def __init__(self, provider: java.nio.channels.spi.SelectorProvider, /) -> None: ...
    def bind(self, arg1: java.net.SocketAddress, /) -> DatagramChannel: ...
    def connect(self, arg1: java.net.SocketAddress, /) -> DatagramChannel: ...
    def disconnect(self) -> DatagramChannel: ...
    def getLocalAddress(self) -> java.net.SocketAddress: ...
    def getRemoteAddress(self) -> java.net.SocketAddress: ...
    def isConnected(self) -> bool: ...
    @typing.overload
    @staticmethod
    def open() -> DatagramChannel: ...
    @typing.overload
    @staticmethod
    def open(family: java.net.ProtocolFamily, /) -> DatagramChannel: ...
    @typing.overload
    def read(self, arg1: java.nio.ByteBuffer, /) -> int: ...
    @typing.overload
    def read(self, dsts: java.chaquopy.JavaArray[java.nio.ByteBuffer], /) -> int: ...
    @typing.overload
    def read(self, arg1: java.chaquopy.JavaArray[java.nio.ByteBuffer], arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> int: ...
    def receive(self, arg1: java.nio.ByteBuffer, /) -> java.net.SocketAddress: ...
    def send(self, arg1: java.nio.ByteBuffer, arg2: java.net.SocketAddress, /) -> int: ...
    _setOption__T = typing.TypeVar('_setOption__T')  # <T>
    def setOption(self, arg1: java.net.SocketOption[_setOption__T], arg2: _setOption__T, /) -> DatagramChannel: ...
    def socket(self) -> java.net.DatagramSocket: ...
    def validOps(self) -> int: ...
    @typing.overload
    def write(self, arg1: java.nio.ByteBuffer, /) -> int: ...
    @typing.overload
    def write(self, srcs: java.chaquopy.JavaArray[java.nio.ByteBuffer], /) -> int: ...
    @typing.overload
    def write(self, arg1: java.chaquopy.JavaArray[java.nio.ByteBuffer], arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> int: ...

class FileChannel(GatheringByteChannel, ScatteringByteChannel, SeekableByteChannel, java.nio.channels.spi.AbstractInterruptibleChannel):
    def __init__(self) -> None: ...
    def force(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def lock(self) -> FileLock: ...
    @typing.overload
    def lock(self, arg1: int | java.jlong | java.lang.Long, arg2: int | java.jlong | java.lang.Long, arg3: bool | java.jboolean | java.lang.Boolean, /) -> FileLock: ...
    def map(self, arg1: FileChannel.MapMode, arg2: int | java.jlong | java.lang.Long, arg3: int | java.jlong | java.lang.Long, /) -> java.nio.MappedByteBuffer: ...
    @typing.overload
    @staticmethod
    def open(path: java.nio.file.Path, /, *options: java.nio.file.OpenOption) -> FileChannel: ...
    @typing.overload
    @staticmethod
    def open(path: java.nio.file.Path, options: java.util.Set[java.nio.file.OpenOption], /, *attrs: java.nio.file.attribute.FileAttribute[java.lang.Object]) -> FileChannel: ...
    @typing.overload
    def position(self) -> int: ...
    @typing.overload
    def position(self, arg1: int | java.jlong | java.lang.Long, /) -> FileChannel: ...
    @typing.overload
    def read(self, arg1: java.nio.ByteBuffer, /) -> int: ...
    @typing.overload
    def read(self, dsts: java.chaquopy.JavaArray[java.nio.ByteBuffer], /) -> int: ...
    @typing.overload
    def read(self, arg1: java.nio.ByteBuffer, arg2: int | java.jlong | java.lang.Long, /) -> int: ...
    @typing.overload
    def read(self, arg1: java.chaquopy.JavaArray[java.nio.ByteBuffer], arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> int: ...
    def size(self) -> int: ...
    def transferFrom(self, arg1: ReadableByteChannel, arg2: int | java.jlong | java.lang.Long, arg3: int | java.jlong | java.lang.Long, /) -> int: ...
    def transferTo(self, arg1: int | java.jlong | java.lang.Long, arg2: int | java.jlong | java.lang.Long, arg3: WritableByteChannel, /) -> int: ...
    def truncate(self, arg1: int | java.jlong | java.lang.Long, /) -> FileChannel: ...
    @typing.overload
    def tryLock(self) -> FileLock: ...
    @typing.overload
    def tryLock(self, arg1: int | java.jlong | java.lang.Long, arg2: int | java.jlong | java.lang.Long, arg3: bool | java.jboolean | java.lang.Boolean, /) -> FileLock: ...
    @typing.overload
    def write(self, arg1: java.nio.ByteBuffer, /) -> int: ...
    @typing.overload
    def write(self, srcs: java.chaquopy.JavaArray[java.nio.ByteBuffer], /) -> int: ...
    @typing.overload
    def write(self, arg1: java.nio.ByteBuffer, arg2: int | java.jlong | java.lang.Long, /) -> int: ...
    @typing.overload
    def write(self, arg1: java.chaquopy.JavaArray[java.nio.ByteBuffer], arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> int: ...

    class MapMode(java.lang.Object):
        PRIVATE: typing.ClassVar[FileChannel.MapMode] = ...
        READ_ONLY: typing.ClassVar[FileChannel.MapMode] = ...
        READ_WRITE: typing.ClassVar[FileChannel.MapMode] = ...
        def toString(self) -> str: ...

class FileLock(java.lang.AutoCloseable):
    @typing.overload
    def __init__(self, channel: AsynchronousFileChannel, position: int | java.jlong | java.lang.Long, size: int | java.jlong | java.lang.Long, shared: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def __init__(self, channel: FileChannel, position: int | java.jlong | java.lang.Long, size: int | java.jlong | java.lang.Long, shared: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def acquiredBy(self) -> Channel: ...
    def channel(self) -> FileChannel: ...
    def close(self) -> None: ...
    def isShared(self) -> bool: ...
    def isValid(self) -> bool: ...
    def overlaps(self, position: int | java.jlong | java.lang.Long, size: int | java.jlong | java.lang.Long, /) -> bool: ...
    def position(self) -> int: ...
    def release(self) -> None: ...
    def size(self) -> int: ...
    def toString(self) -> str: ...

class FileLockInterruptionException(java.io.IOException):
    def __init__(self) -> None: ...

class GatheringByteChannel(WritableByteChannel):
    @typing.overload
    def write(self, arg1: java.chaquopy.JavaArray[java.nio.ByteBuffer], /) -> int: ...
    @typing.overload
    def write(self, arg1: java.chaquopy.JavaArray[java.nio.ByteBuffer], arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> int: ...

class IllegalBlockingModeException(java.lang.IllegalStateException):
    def __init__(self) -> None: ...

class IllegalChannelGroupException(java.lang.IllegalArgumentException):
    def __init__(self) -> None: ...

class IllegalSelectorException(java.lang.IllegalArgumentException):
    def __init__(self) -> None: ...

class InterruptedByTimeoutException(java.io.IOException):
    def __init__(self) -> None: ...

class InterruptibleChannel(Channel):
    def close(self) -> None: ...

class MembershipKey(java.lang.Object):
    def __init__(self) -> None: ...
    def block(self, arg1: java.net.InetAddress, /) -> MembershipKey: ...
    def channel(self) -> MulticastChannel: ...
    def drop(self) -> None: ...
    def group(self) -> java.net.InetAddress: ...
    def isValid(self) -> bool: ...
    def networkInterface(self) -> java.net.NetworkInterface: ...
    def sourceAddress(self) -> java.net.InetAddress: ...
    def unblock(self, arg1: java.net.InetAddress, /) -> MembershipKey: ...

class MulticastChannel(NetworkChannel):
    def close(self) -> None: ...
    @typing.overload
    def join(self, arg1: java.net.InetAddress, arg2: java.net.NetworkInterface, /) -> MembershipKey: ...
    @typing.overload
    def join(self, arg1: java.net.InetAddress, arg2: java.net.NetworkInterface, arg3: java.net.InetAddress, /) -> MembershipKey: ...

class NetworkChannel(Channel):
    def bind(self, arg1: java.net.SocketAddress, /) -> NetworkChannel: ...
    def getLocalAddress(self) -> java.net.SocketAddress: ...
    _getOption__T = typing.TypeVar('_getOption__T')  # <T>
    def getOption(self, arg1: java.net.SocketOption[_getOption__T], /) -> _getOption__T: ...
    _setOption__T = typing.TypeVar('_setOption__T')  # <T>
    def setOption(self, arg1: java.net.SocketOption[_setOption__T], arg2: _setOption__T, /) -> NetworkChannel: ...
    def supportedOptions(self) -> java.util.Set[java.net.SocketOption[java.lang.Object]]: ...

class NoConnectionPendingException(java.lang.IllegalStateException):
    def __init__(self) -> None: ...

class NonReadableChannelException(java.lang.IllegalStateException):
    def __init__(self) -> None: ...

class NonWritableChannelException(java.lang.IllegalStateException):
    def __init__(self) -> None: ...

class NotYetBoundException(java.lang.IllegalStateException):
    def __init__(self) -> None: ...

class NotYetConnectedException(java.lang.IllegalStateException):
    def __init__(self) -> None: ...

class OverlappingFileLockException(java.lang.IllegalStateException):
    def __init__(self) -> None: ...

class Pipe(java.lang.Object):
    def __init__(self) -> None: ...
    @staticmethod
    def open() -> Pipe: ...
    def sink(self) -> Pipe.SinkChannel: ...
    def source(self) -> Pipe.SourceChannel: ...

    class SourceChannel(ScatteringByteChannel, ReadableByteChannel, java.nio.channels.spi.AbstractSelectableChannel):
        def __init__(self, provider: java.nio.channels.spi.SelectorProvider, /) -> None: ...
        def validOps(self) -> int: ...

    class SinkChannel(GatheringByteChannel, WritableByteChannel, java.nio.channels.spi.AbstractSelectableChannel):
        def __init__(self, provider: java.nio.channels.spi.SelectorProvider, /) -> None: ...
        def validOps(self) -> int: ...

class ReadPendingException(java.lang.IllegalStateException):
    def __init__(self) -> None: ...

class ReadableByteChannel(Channel):
    def read(self, arg1: java.nio.ByteBuffer, /) -> int: ...

class ScatteringByteChannel(ReadableByteChannel):
    @typing.overload
    def read(self, arg1: java.chaquopy.JavaArray[java.nio.ByteBuffer], /) -> int: ...
    @typing.overload
    def read(self, arg1: java.chaquopy.JavaArray[java.nio.ByteBuffer], arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> int: ...

class SeekableByteChannel(ByteChannel):
    @typing.overload
    def position(self) -> int: ...
    @typing.overload
    def position(self, arg1: int | java.jlong | java.lang.Long, /) -> SeekableByteChannel: ...
    def read(self, arg1: java.nio.ByteBuffer, /) -> int: ...
    def size(self) -> int: ...
    def truncate(self, arg1: int | java.jlong | java.lang.Long, /) -> SeekableByteChannel: ...
    def write(self, arg1: java.nio.ByteBuffer, /) -> int: ...

class SelectableChannel(Channel, java.nio.channels.spi.AbstractInterruptibleChannel):
    def __init__(self) -> None: ...
    def blockingLock(self) -> java.lang.Object: ...
    def configureBlocking(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> SelectableChannel: ...
    def isBlocking(self) -> bool: ...
    def isRegistered(self) -> bool: ...
    def keyFor(self, arg1: Selector, /) -> SelectionKey: ...
    def provider(self) -> java.nio.channels.spi.SelectorProvider: ...
    @typing.overload
    def register(self, sel: Selector, ops: int | java.jint | java.lang.Integer, /) -> SelectionKey: ...
    @typing.overload
    def register(self, arg1: Selector, arg2: int | java.jint | java.lang.Integer, arg3: java.lang.Object | int | bool | float | str, /) -> SelectionKey: ...
    def validOps(self) -> int: ...

class SelectionKey(java.lang.Object):
    OP_ACCEPT: typing.ClassVar[int] = ...
    OP_CONNECT: typing.ClassVar[int] = ...
    OP_READ: typing.ClassVar[int] = ...
    OP_WRITE: typing.ClassVar[int] = ...
    def __init__(self) -> None: ...
    def attach(self, ob: java.lang.Object | int | bool | float | str, /) -> java.lang.Object: ...
    def attachment(self) -> java.lang.Object: ...
    def cancel(self) -> None: ...
    def channel(self) -> SelectableChannel: ...
    @typing.overload
    def interestOps(self) -> int: ...
    @typing.overload
    def interestOps(self, arg1: int | java.jint | java.lang.Integer, /) -> SelectionKey: ...
    def interestOpsAnd(self, ops: int | java.jint | java.lang.Integer, /) -> int: ...
    def interestOpsOr(self, ops: int | java.jint | java.lang.Integer, /) -> int: ...
    def isAcceptable(self) -> bool: ...
    def isConnectable(self) -> bool: ...
    def isReadable(self) -> bool: ...
    def isValid(self) -> bool: ...
    def isWritable(self) -> bool: ...
    def readyOps(self) -> int: ...
    def selector(self) -> Selector: ...

class Selector(java.io.Closeable):
    def __init__(self) -> None: ...
    def close(self) -> None: ...
    def isOpen(self) -> bool: ...
    def keys(self) -> java.util.Set[SelectionKey]: ...
    @staticmethod
    def open() -> Selector: ...
    def provider(self) -> java.nio.channels.spi.SelectorProvider: ...
    @typing.overload
    def select(self) -> int: ...
    @typing.overload
    def select(self, arg1: int | java.jlong | java.lang.Long, /) -> int: ...
    @typing.overload
    def select(self, action: java.util.function.Consumer[SelectionKey], /) -> int: ...
    @typing.overload
    def select(self, action: java.util.function.Consumer[SelectionKey], timeout: int | java.jlong | java.lang.Long, /) -> int: ...
    @typing.overload
    def selectNow(self) -> int: ...
    @typing.overload
    def selectNow(self, action: java.util.function.Consumer[SelectionKey], /) -> int: ...
    def selectedKeys(self) -> java.util.Set[SelectionKey]: ...
    def wakeup(self) -> Selector: ...

class ServerSocketChannel(NetworkChannel, java.nio.channels.spi.AbstractSelectableChannel):
    def __init__(self, provider: java.nio.channels.spi.SelectorProvider, /) -> None: ...
    def accept(self) -> SocketChannel: ...
    @typing.overload
    def bind(self, local: java.net.SocketAddress, /) -> ServerSocketChannel: ...
    @typing.overload
    def bind(self, arg1: java.net.SocketAddress, arg2: int | java.jint | java.lang.Integer, /) -> ServerSocketChannel: ...
    def getLocalAddress(self) -> java.net.SocketAddress: ...
    @staticmethod
    def open() -> ServerSocketChannel: ...
    _setOption__T = typing.TypeVar('_setOption__T')  # <T>
    def setOption(self, arg1: java.net.SocketOption[_setOption__T], arg2: _setOption__T, /) -> ServerSocketChannel: ...
    def socket(self) -> java.net.ServerSocket: ...
    def validOps(self) -> int: ...

class ShutdownChannelGroupException(java.lang.IllegalStateException):
    def __init__(self) -> None: ...

class SocketChannel(ByteChannel, GatheringByteChannel, NetworkChannel, ScatteringByteChannel, java.nio.channels.spi.AbstractSelectableChannel):
    def __init__(self, provider: java.nio.channels.spi.SelectorProvider, /) -> None: ...
    def bind(self, arg1: java.net.SocketAddress, /) -> SocketChannel: ...
    def connect(self, arg1: java.net.SocketAddress, /) -> bool: ...
    def finishConnect(self) -> bool: ...
    def getLocalAddress(self) -> java.net.SocketAddress: ...
    def getRemoteAddress(self) -> java.net.SocketAddress: ...
    def isConnected(self) -> bool: ...
    def isConnectionPending(self) -> bool: ...
    @typing.overload
    @staticmethod
    def open() -> SocketChannel: ...
    @typing.overload
    @staticmethod
    def open(remote: java.net.SocketAddress, /) -> SocketChannel: ...
    @typing.overload
    def read(self, arg1: java.nio.ByteBuffer, /) -> int: ...
    @typing.overload
    def read(self, dsts: java.chaquopy.JavaArray[java.nio.ByteBuffer], /) -> int: ...
    @typing.overload
    def read(self, arg1: java.chaquopy.JavaArray[java.nio.ByteBuffer], arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> int: ...
    _setOption__T = typing.TypeVar('_setOption__T')  # <T>
    def setOption(self, arg1: java.net.SocketOption[_setOption__T], arg2: _setOption__T, /) -> SocketChannel: ...
    def shutdownInput(self) -> SocketChannel: ...
    def shutdownOutput(self) -> SocketChannel: ...
    def socket(self) -> java.net.Socket: ...
    def validOps(self) -> int: ...
    @typing.overload
    def write(self, arg1: java.nio.ByteBuffer, /) -> int: ...
    @typing.overload
    def write(self, srcs: java.chaquopy.JavaArray[java.nio.ByteBuffer], /) -> int: ...
    @typing.overload
    def write(self, arg1: java.chaquopy.JavaArray[java.nio.ByteBuffer], arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> int: ...

class UnresolvedAddressException(java.lang.IllegalArgumentException):
    def __init__(self) -> None: ...

class UnsupportedAddressTypeException(java.lang.IllegalArgumentException):
    def __init__(self) -> None: ...

class WritableByteChannel(Channel):
    def write(self, arg1: java.nio.ByteBuffer, /) -> int: ...

class WritePendingException(java.lang.IllegalStateException):
    def __init__(self) -> None: ...
